color property

Color get color

The color of the animation as it was in Spine, or a default color if nonessential data was not exported.

Implementation

Color get color {
  final result = SpineBindings.bindings.spine_animation_get_color(_ptr);
  return Color.fromPointer(result);
}