timelines property
ArrayTimeline
get
timelines
If this list or the timelines it contains are modified, the timelines and bones must be set again to recompute the animation's bone indices and timeline property IDs.
See setTimelines().
Implementation
ArrayTimeline get timelines {
final result = SpineBindings.bindings.spine_animation_get_timelines(_ptr);
return ArrayTimeline.fromPointer(result);
}