generated/api
library
Classes
AlphaTimeline
AlphaTimeline wrapper
Animation
Stores a list of timelines to animate a skeleton's pose over time.
AnimationState
Applies animations over time, queues animations for later playback, mixes
(crossfading) between animations, and applies multiple animations on top of
each other (layering).
AnimationStateData
Stores mix (crossfade) durations to be applied when AnimationState
animations are changed on the same track.
ArrayAnimation
ArrayAnimation wrapper
ArrayAtlasPage
ArrayAtlasPage wrapper
ArrayAtlasRegion
ArrayAtlasRegion wrapper
ArrayAttachment
ArrayAttachment wrapper
ArrayBone
ArrayBone wrapper
ArrayBoneData
ArrayBoneData wrapper
ArrayBonePose
ArrayBonePose wrapper
ArrayBoundingBoxAttachment
ArrayBoundingBoxAttachment wrapper
ArrayConstraint
ArrayConstraint wrapper
ArrayConstraintData
ArrayConstraintData wrapper
ArrayEvent
ArrayEvent wrapper
ArrayEventData
ArrayEventData wrapper
ArrayFloat
ArrayFloat wrapper
ArrayFromProperty
ArrayFromProperty wrapper
ArrayInt
ArrayInt wrapper
ArrayPhysicsConstraint
ArrayPhysicsConstraint wrapper
ArrayPolygon
ArrayPolygon wrapper
ArrayPropertyId
ArrayPropertyId wrapper
ArraySkin
ArraySkin wrapper
ArraySlot
ArraySlot wrapper
ArraySlotData
ArraySlotData wrapper
ArrayTextureRegion
ArrayTextureRegion wrapper
ArrayTimeline
ArrayTimeline wrapper
ArrayToProperty
ArrayToProperty wrapper
ArrayTrackEntry
ArrayTrackEntry wrapper
ArrayUnsignedShort
ArrayUnsignedShort wrapper
ArrayUpdate
ArrayUpdate wrapper
Atlas
Atlas wrapper
AtlasAttachmentLoader
An AttachmentLoader that configures attachments using texture regions from
an Atlas.
AtlasPage
AtlasPage wrapper
AtlasRegion
AtlasRegion wrapper
Attachment
The base class for all attachments. Multiple Skeleton instances, slots, or
skins can use the same attachments.
AttachmentLoader
AttachmentLoader wrapper
AttachmentTimeline
AttachmentTimeline wrapper
Bone
A node in a skeleton's hierarchy with a transform that affects its children
and their attachments. A bone has a number of poses: - getData(): The setup
pose data. - getPose(): The unconstrained local pose. Set by animations and
application code. - getAppliedPose(): The local pose to use for rendering.
Possibly modified by constraints. - World transform: the local pose combined
with the parent world transform. Computed on a pose by
BonePose::updateWorldTransform(Skeleton) and
Skeleton::updateWorldTransform(Physics).
BoneData
BoneData wrapper
BoneLocal
Stores a bone's local pose.
BonePose
The applied local pose and world transform for a bone. This is the bone's
unconstrained pose with constraints applied and the world transform computed
by Skeleton::updateWorldTransform(Physics) and
updateWorldTransform(Skeleton).
BoneTimeline
An interface for timelines which change the property of a bone.
BoneTimeline1
Base class for timelines that animate a single bone property.
BoneTimeline2
Base class for timelines that animate two bone properties.
BoundingBoxAttachment
Attachment that has a polygon for bounds checking.
ClippingAttachment
ClippingAttachment wrapper
Color
Color wrapper
Constraint
Constraint wrapper
ConstraintData
ConstraintData wrapper
ConstraintTimeline
An interface for timelines which change the property of a constraint.
ConstraintTimeline1
The base class for timelines that change 1 constraint property with a curve.
CurveTimeline
Base class for frames that use an interpolation bezier curve.
CurveTimeline1
The base class for a CurveTimeline that sets one property.
DeformTimeline
Changes a slot's deform to deform a VertexAttachment.
DrawOrder
Stores the skeleton's draw order, which is the order that each slot's
attachment is rendered.
DrawOrderFolderTimeline
Changes a subset of the Skeleton::getDrawOrder() draw order.
DrawOrderTimeline
Changes the Skeleton::getDrawOrder().
Event
Fired by EventTimeline when specific animation times are reached.
EventData
Stores the setup pose values for an Event.
EventQueueEntry
EventQueueEntry wrapper
EventTimeline
Fires an Event when specific animation times are reached.
FromProperty
Source property for a TransformConstraint.
FromRotate
FromRotate wrapper
FromScaleX
FromScaleX wrapper
FromScaleY
FromScaleY wrapper
FromShearY
FromShearY wrapper
FromX
FromX wrapper
FromY
FromY wrapper
IkConstraint
IkConstraint wrapper
IkConstraintBase
Non-exported base class that inherits from the template
IkConstraintData
IkConstraintData wrapper
IkConstraintPose
Stores a pose for an IK constraint.
IkConstraintTimeline
Changes an IK constraint's mix, softness, bend direction, stretch, and
compress values.
InheritTimeline
Changes a bone's inherit mode.
Interpolation
Takes a linear value in the range 0-1 and outputs a usually non-linear,
interpolated value.
LinkedMesh
LinkedMesh wrapper
MeshAttachment
Attachment that displays a texture region using a mesh.
PathAttachment
PathAttachment wrapper
PathConstraint
PathConstraint wrapper
PathConstraintBase
Adjusts the rotation, translation, and scale of the constrained bones so
they follow a PathAttachment.
PathConstraintData
Stores the setup pose for a PathConstraint.
PathConstraintMixTimeline
Changes a path constraint's rotate, x, and y mix values.
PathConstraintPose
Stores a pose for a path constraint.
PathConstraintPositionTimeline
Changes a path constraint's position.
PathConstraintSpacingTimeline
Changes a path constraint's spacing.
PhysicsConstraint
PhysicsConstraint wrapper
PhysicsConstraintBase
Applies physics to a bone.
PhysicsConstraintDampingTimeline
Changes a physics constraint's damping.
PhysicsConstraintData
Stores the setup pose for a PhysicsConstraint.
PhysicsConstraintGravityTimeline
Changes a physics constraint's gravity.
PhysicsConstraintInertiaTimeline
Changes a physics constraint's inertia.
PhysicsConstraintMassTimeline
Changes a physics constraint's mass inverse. The timeline values are not
inverted.
PhysicsConstraintMixTimeline
Changes a physics constraint's mix.
PhysicsConstraintPose
Stores a pose for a physics constraint.
PhysicsConstraintResetTimeline
Resets a physics constraint when specific animation times are reached.
PhysicsConstraintStrengthTimeline
Changes a physics constraint's strength.
PhysicsConstraintTimeline
The base class for most PhysicsConstraint timelines.
PhysicsConstraintWindTimeline
Changes a physics constraint's wind.
PointAttachment
An attachment which is a single point and a rotation. This can be used to
spawn projectiles, particles, etc. A bone can be used in similar ways, but a
PointAttachment is slightly less expensive to compute and can be hidden,
shown, and placed in a skin.
Polygon
Polygon wrapper
Posed
Base interface for posed objects.
PosedActive
A posed object that may be active or inactive.
PosedData
PosedData wrapper
RegionAttachment
Attachment that displays a texture region.
RenderCommand
RenderCommand wrapper
Rgb2Timeline
Changes RGB for a slot's light and dark colors for two color tinting.
Rgba2Timeline
Changes a slot's light and dark colors for two color tinting.
RgbaTimeline
Changes a slot's color.
RgbTimeline
Changes RGB for a slot's color.
RotateTimeline
Changes a bone's local rotation.
Rtti
Rtti wrapper
ScaleTimeline
Changes a bone's local scaleX and scaleY.
ScaleXTimeline
Changes a bone's local scaleX.
ScaleYTimeline
Changes a bone's local scaleY.
Sequence
Holds texture regions, UVs, and vertex offsets for rendering a region or
mesh attachment. Regions must be populated and update() called before use.
SequenceTimeline
Changes the sequence index for an attachment's Sequence.
ShearTimeline
Changes a bone's local shearX and shearY.
ShearXTimeline
Changes a bone's local shearX.
ShearYTimeline
Changes a bone's local shearY.
Skeleton
Stores bones and slots to be posed by animations and application code.
Multiple skeleton instances can share the same SkeletonData, including
animations, attachments, and skins.
SkeletonBinary
SkeletonBinary wrapper
SkeletonBounds
Collects each BoundingBoxAttachment that is visible and computes the world
vertices for its polygon. The polygon vertices are provided along with
convenience methods for doing hit detection.
SkeletonClipping
SkeletonClipping wrapper
SkeletonData
Stores the setup pose and all of the stateless data for a skeleton.
SkeletonJson
SkeletonJson wrapper
SkeletonRenderer
SkeletonRenderer wrapper
Skin
Stores attachments by slot index and placeholder name. Multiple Skeleton
instances can use the same skins. See SkeletonData::getDefaultSkin,
Skeleton::getSkin, and http://esotericsoftware.com/spine-runtime-skins in
the Spine Runtimes Guide.
Slider
Slider wrapper
SliderBase
Applies an animation based on either the slider's SliderPose::getTime() or a
bone's transform property.
SliderData
Stores the setup pose for a Slider
SliderMixTimeline
Changes a slider's mix.
SliderPose
Stores a pose for a slider.
SliderTimeline
Changes a slider's time.
Slot
Organizes attachments for Skeleton drawOrder purposes and provide a place to
store state for an attachment.
SlotCurveTimeline
Base class for slot timelines that use curves.
SlotData
Stores the setup pose for a Slot.
SlotPose
Stores a slot's pose.
SlotTimeline
An interface for timelines which change the property of a slot.
TextureRegion
TextureRegion wrapper
Timeline
The base class for all timelines.
ToProperty
Constrained property for a TransformConstraint.
ToRotate
ToRotate wrapper
ToScaleX
ToScaleX wrapper
ToScaleY
ToScaleY wrapper
ToShearY
ToShearY wrapper
ToX
ToX wrapper
ToY
ToY wrapper
TrackEntry
State for the playback of an animation
TransformConstraint
Adjusts the world transform of the constrained bones to match that of the
source bone.
TransformConstraintBase
Non-exported base class that inherits from the template
TransformConstraintData
Stores the setup pose for a TransformConstraint.
TransformConstraintPose
Stores a pose for a transform constraint.
TransformConstraintTimeline
Changes a transform constraint's rotate, x, y, scaleX, scaleY, and shearY
mix values.
TranslateTimeline
Changes a bone's local X and Y translation.
TranslateXTimeline
Changes a bone's local X translation.
TranslateYTimeline
Changes a bone's local Y translation.
Update
The interface for items updated by Skeleton::updateWorldTransform().
VertexAttachment
An attachment with vertices that are transformed by one or more bones and
can be deformed by SlotPose::getDeform().