AtlasPage class

AtlasPage wrapper

Constructors

AtlasPage(String inName)
factory
AtlasPage.fromPointer(Pointer<spine_atlas_page_wrapper> _ptr)

Properties

format ↔ Format
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
index ↔ int
getter/setter pair
magFilter ↔ TextureFilter
getter/setter pair
minFilter ↔ TextureFilter
getter/setter pair
name ↔ String
getter/setter pair
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
pma ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → Pointer<Void>?
no setter
texturePath ↔ String
getter/setter pair
uWrap ↔ TextureWrap
getter/setter pair
vWrap ↔ TextureWrap
getter/setter pair
width ↔ int
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited