Attachment class abstract

The base class for all attachments. Multiple Skeleton instances, slots, or skins can use the same attachments.

Implementers

Constructors

Attachment.fromPointer(Pointer<spine_attachment_wrapper> _ptr)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
refCount int
no setter
rtti Rtti
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timelineAttachment Attachment?
getter/setter pair
timelineSlots ArrayInt
getter/setter pair

Methods

copy() Attachment
dereference() → void
isTimelineActive(ArraySlot slots, int slotIndex, bool appliedPose) bool
Returns true if the slotIndex or any getTimelineSlots() have an attachment whose getTimelineAttachment() is this attachment.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reference() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rttiStatic() Rtti