generated/bone library

Classes

Bone
A node in a skeleton's hierarchy with a transform that affects its children and their attachments. A bone has a number of poses: - getData(): The setup pose data. - getPose(): The unconstrained local pose. Set by animations and application code. - getAppliedPose(): The local pose to use for rendering. Possibly modified by constraints. - World transform: the local pose combined with the parent world transform. Computed on a pose by BonePose::updateWorldTransform(Skeleton) and Skeleton::updateWorldTransform(Physics).