updateLocalTransform method

void updateLocalTransform(
  1. Skeleton skeleton
)

Computes the local transform values from the world transform.

Some information is ambiguous in the world transform, such as -1,-1 scale versus 180 rotation. The local transform after calling this method is equivalent to the local transform used to compute the world transform, but may not be identical.

Implementation

void updateLocalTransform(Skeleton skeleton) {
  SpineBindings.bindings.spine_bone_pose_update_local_transform(_ptr, skeleton.nativePtr.cast());
}