validateLocalTransform method
If the world transform has been modified by constraints and the local transform no longer matches, updateLocalTransform() is called. Call this after Skeleton::updateWorldTransform(Physics) before using the applied local transform.
Implementation
void validateLocalTransform(Skeleton skeleton) {
SpineBindings.bindings.spine_bone_pose_validate_local_transform(_ptr, skeleton.nativePtr.cast());
}