CurveTimeline class abstract

Base class for frames that use an interpolation bezier curve.

Inheritance
Implementers

Properties

additive bool
True if this timeline supports additive blending.
no setterinherited
curves ArrayFloat
no setter
duration double
no setterinherited
frameCount int
no setterinherited
frameEntries int
no setterinherited
frames ArrayFloat
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
instant bool
True if this timeline sets values instantaneously and does not support interpolation between frames.
no setterinherited
linear int
no getter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
propertyIds ArrayPropertyId
no setterinherited
rtti Rtti
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepped int
no getter

Methods

apply(Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void
Applies this timeline to the skeleton.
inherited
getBezierValue(double time, int frame, int valueOffset, int i) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBezier(int bezier, int frame, double value, double time1, double value1, double cx1, double cy1, double cx2, double cy2, double time2, double value2) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited