DeformTimeline class

Changes a slot's deform to deform a VertexAttachment.

Inheritance

Constructors

DeformTimeline(int frameCount, int bezierCount, int slotIndex, VertexAttachment attachment)
factory
DeformTimeline.fromPointer(Pointer<spine_deform_timeline_wrapper> _ptr)

Properties

additive → bool
True if this timeline supports additive blending.
no setterinherited
attachment ↔ VertexAttachment
The attachment whose vertices will be deformed.
getter/setter pair
curves → ArrayFloat
no setterinherited
duration → double
no setterinherited
frameCount → int
no setterinherited
frameEntries → int
no setterinherited
frames → ArrayFloat
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
instant → bool
True if this timeline sets values instantaneously and does not support interpolation between frames.
no setterinherited
linear ← int
no getterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
propertyIds → ArrayPropertyId
no setterinherited
rtti → Rtti
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotIndex ↔ int
getter/setter pairinherited
stepped ← int
no getterinherited

Methods

apply(Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void
Applies this timeline to the skeleton.
inherited
dispose() → void
getBezierValue(double time, int frame, int valueOffset, int i) → double
inherited
getCurvePercent(double time, int frame) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBezier(int bezier, int frame, double value, double time1, double value1, double cx1, double cy1, double cx2, double cy2, double time2, double value2) → void
inherited
setFrame(int frameIndex, double time, ArrayFloat vertices) → void
Sets the time and vertices for the specified frame.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited