DrawOrder class

Stores the skeleton's draw order, which is the order that each slot's attachment is rendered.

Constructors

DrawOrder(ArraySlot setupPose)
factory
DrawOrder.fromPointer(Pointer<spine_draw_order_wrapper> _ptr)

Properties

appliedPose ArraySlot
The constrained draw order for rendering. If no constraints modify the draw order, this is the same as getPose(). Otherwise it is a copy of getPose() modified by constraints.
no setter
hashCode int
The hash code for this object.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
pose ArraySlot
The unconstrained draw order, set by animations and application code.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setupPose() → void
Sets the unconstrained draw order to the setup pose order.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited