setupPose method
void
setupPose()
Sets the unconstrained draw order to the setup pose order.
Implementation
void setupPose() {
SpineBindings.bindings.spine_draw_order_setup_pose(_ptr);
}
Sets the unconstrained draw order to the setup pose order.
void setupPose() {
SpineBindings.bindings.spine_draw_order_setup_pose(_ptr);
}