Event class

Fired by EventTimeline when specific animation times are reached.

See Timeline::apply(), AnimationStateListener::event(), and https://esotericsoftware.com/spine-events Events in the Spine User Guide.

Constructors

Event(double time, EventData data)
factory
Event.fromPointer(Pointer<spine_event_wrapper> _ptr)

Properties

balance double
If an audio path is set, the left/right balance for the audio.
getter/setter pair
data EventData
The event's setup pose data.
no setter
floatValue double
The float payload for this event.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intValue int
The integer payload for this event.
getter/setter pair
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String
The string payload for this event.
getter/setter pair
time double
The animation time this event was keyed, or -1 for the setup pose.
no setter
volume double
If an audio path is set, the volume for the audio.
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited