EventQueueEntry class

EventQueueEntry wrapper

Constructors

EventQueueEntry(EventType eventType, TrackEntry? trackEntry, Event? event)
factory
EventQueueEntry.fromPointer(Pointer<spine_event_queue_entry_wrapper> _ptr)

Properties

entry ↔ TrackEntry?
getter/setter pair
event ↔ Event?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ EventType
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited