FromRotate class

FromRotate wrapper

Inheritance

Constructors

FromRotate()
factory
FromRotate.fromPointer(Pointer<spine_from_rotate_wrapper> _ptr)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
offset ↔ double
getter/setter pairinherited
rtti → Rtti
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to ↔ ArrayToProperty?
getter/setter pairinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited