IkConstraintData class

IkConstraintData wrapper

Inheritance
Implemented types

Properties

bones ArrayBoneData
The bones that are constrained by this IK Constraint.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
rtti Rtti
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleYMode ScaleYMode
Determines how BonePose::getScaleY() changes when IkConstraintPose::getCompress() or IkConstraintPose::getStretch() sets BonePose::getScaleX().
getter/setter pair
setupPose IkConstraintPose
The setup pose that most animations are relative to.
no setter
skinRequired bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited
target BoneData
The bone that is the IK target.
getter/setter pair

Methods

createMethod(Skeleton skeleton) Constraint
override
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rttiStatic() Rtti
override