Inherit enum

Inherit enum

Inheritance
Available extensions

Values

normal → const Inherit
const Inherit(0)
onlyTranslation → const Inherit
const Inherit(1)
noRotationOrReflection → const Inherit
const Inherit(2)
noScale → const Inherit
const Inherit(3)
noScaleOrReflection → const Inherit
const Inherit(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → Inherit

Constants

values → const List<Inherit>
A constant List of the values in this enum, in order of their declaration.