Interpolation class

Takes a linear value in the range 0-1 and outputs a usually non-linear, interpolated value.

Properties

hashCode int
The hash code for this object.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(double a) double
a Alpha value between 0 and 1.
apply2(double start, double end, double a) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

circle() Interpolation
fastSlow() Interpolation
Fast, then slow.
linear() Interpolation
slowFast() Interpolation
Slow, then fast.
smooth() Interpolation
Aka "smoothstep".