PathConstraintBase class abstract
Adjusts the rotation, translation, and scale of the constrained bones so they follow a PathAttachment.
See https://esotericsoftware.com/spine-path-constraints Path constraints in the Spine User Guide. Non-exported base class that inherits from the template
- Inheritance
-
- Object
- PosedActive
- PathConstraintBase
- Implemented types
- Implementers
Constructors
-
PathConstraintBase.fromPointer(Pointer<
spine_path_constraint_base_wrapper> _ptr)
Properties
- active ← bool
-
no getterinherited
- appliedPose → PathConstraintPose
-
The pose to use for rendering. If no constraints modify this pose, this is
the same as getPose(). Otherwise it is a copy of getPose() modified by
constraints.
no setter
- data → PathConstraintData
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Returns false when this won't be updated by
Skeleton::updateWorldTransform(Physics) because a skin is required and the
active skin does not contain this item. See Skin::getBones(),
Skin::getConstraints(), PosedData::getSkinRequired(), and
Skeleton::updateCache().
no setterinherited
- isPoseEqualToApplied → bool
-
no setteroverride
- isSourceActive → bool
-
no setteroverride
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- pose → PathConstraintPose
-
The unconstrained pose for this object, set by animations and application
code.
no setter
- rtti → Rtti
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrained(
) → void -
Sets the applied pose to the constrained pose, in anticipation of the
applied pose being modified by constraints.
override
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetConstrained(
) → void -
Sets the constrained pose to the unconstrained pose, as a starting point
for constraints to be applied.
override
-
sort(
Skeleton skeleton) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Skeleton skeleton, Physics physics) → void -
Inherited from Update
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
rttiStatic(
) → Rtti -
override