PathConstraintPose class

Stores a pose for a path constraint.

Properties

hashCode → int
The hash code for this object.
no setterinherited
mixRotate ↔ double
A percentage (0-1) that controls the mix between the constrained and unconstrained rotation.
getter/setter pair
mixX ↔ double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation X.
getter/setter pair
mixY ↔ double
A percentage (0-1) that controls the mix between the constrained and unconstrained translation Y.
getter/setter pair
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
position ↔ double
The position along the path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing ↔ double
The spacing between bones.
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(PathConstraintPose pose) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited