reset method

void reset(
  1. Skeleton skeleton
)

Resets all physics state that was the result of previous movement. Use this after moving a bone to prevent physics from reacting to the movement.

Implementation

void reset(Skeleton skeleton) {
  SpineBindings.bindings.spine_physics_constraint_reset(_ptr, skeleton.nativePtr.cast());
}