constrained method
Sets the applied pose to the constrained pose, in anticipation of the applied pose being modified by constraints.
Implementation
@override
void constrained() {
SpineBindings.bindings.spine_physics_constraint_base_constrained(_ptr);
}