PhysicsConstraintPose class

Stores a pose for a physics constraint.

Properties

damping double
Reduces the speed of physics movements, with more of a reduction at higher speeds.
getter/setter pair
gravity double
Applies a constant force along the Skeleton::getGravityX(), Skeleton::getGravityY() vector.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inertia double
Controls how much bone movement is converted into physics movement.
getter/setter pair
massInverse double
Determines susceptibility to acceleration.
getter/setter pair
mix double
A percentage (0+) that controls the mix between the constrained and unconstrained poses.
getter/setter pair
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
The amount of force used to return properties to the unconstrained value.
getter/setter pair
wind double
Applies a constant force along the Skeleton::getWindX(), Skeleton::getWindY() vector.
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(PhysicsConstraintPose pose) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited