PointAttachment class

An attachment which is a single point and a rotation. This can be used to spawn projectiles, particles, etc. A bone can be used in similar ways, but a PointAttachment is slightly less expensive to compute and can be hidden, shown, and placed in a skin.

See https://esotericsoftware.com/spine-points for Point Attachments in the Spine User Guide.

Inheritance

Properties

color → Color
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
refCount → int
no setterinherited
rotation ↔ double
The local rotation in degrees, counter clockwise.
getter/setter pair
rtti → Rtti
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timelineAttachment ↔ Attachment?
getter/setter pairinherited
timelineSlots ↔ ArrayInt
getter/setter pairinherited
x ↔ double
The local x position.
getter/setter pair
y ↔ double
The local y position.
getter/setter pair

Methods

computeWorldRotation(BonePose bone) → double
Computes the world rotation from the local rotation.
copy() → Attachment
inherited
dereference() → void
inherited
dispose() → void
isTimelineActive(ArraySlot slots, int slotIndex, bool appliedPose) → bool
Returns true if the slotIndex or any getTimelineSlots() have an attachment whose getTimelineAttachment() is this attachment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reference() → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited