PosedData class

PosedData wrapper

Implementers

Constructors

PosedData(String name)
factory
PosedData.fromPointer(Pointer<spine_posed_data_wrapper> _ptr)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skinRequired bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited