Property enum

Property enum

Inheritance
Available extensions

Values

rotate → const Property
const Property(0)
x → const Property
const Property(1)
y → const Property
const Property(2)
scaleX → const Property
const Property(3)
scaleY → const Property
const Property(4)
shearX → const Property
const Property(5)
shearY → const Property
const Property(6)
inherit → const Property
const Property(7)
rgb → const Property
const Property(8)
alpha → const Property
const Property(9)
rgb2 → const Property
const Property(10)
attachment → const Property
const Property(11)
deform → const Property
const Property(12)
event → const Property
const Property(13)
drawOrder → const Property
const Property(14)
ikConstraint → const Property
const Property(15)
transformConstraint → const Property
const Property(16)
pathConstraintPosition → const Property
const Property(17)
pathConstraintSpacing → const Property
const Property(18)
pathConstraintMix → const Property
const Property(19)
physicsConstraintInertia → const Property
const Property(20)
physicsConstraintStrength → const Property
const Property(21)
physicsConstraintDamping → const Property
const Property(22)
physicsConstraintMass → const Property
const Property(23)
physicsConstraintWind → const Property
const Property(24)
physicsConstraintGravity → const Property
const Property(25)
physicsConstraintMix → const Property
const Property(26)
physicsConstraintReset → const Property
const Property(27)
sequence → const Property
const Property(28)
sliderTime → const Property
const Property(29)
sliderMix → const Property
const Property(30)
drawOrderFolder → const Property
const Property(31)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) Property

Constants

values → const List<Property>
A constant List of the values in this enum, in order of their declaration.