Sequence constructor

Sequence(
  1. int count,
  2. bool pathSuffix
)

count The number of texture regions this sequence will display. pathSuffix If true, getPath(String, int) has a numeric suffix. If false, all regions will use the same path, so count should be 1.

Implementation

factory Sequence(int count, bool pathSuffix) {
  final ptr = SpineBindings.bindings.spine_sequence_create(count, pathSuffix);
  return Sequence.fromPointer(ptr);
}