SequenceTimeline class

Changes the sequence index for an attachment's Sequence.

Inheritance
Implemented types

Constructors

SequenceTimeline(int frameCount, int slotIndex, Attachment attachment)
factory
SequenceTimeline.fromPointer(Pointer<spine_sequence_timeline_wrapper> _ptr)

Properties

additive bool
True if this timeline supports additive blending.
no setterinherited
attachment Attachment
The attachment for which the sequence index will be set.
no setter
duration double
no setterinherited
frameCount int
no setterinherited
frameEntries int
no setterinherited
frames ArrayFloat
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
instant bool
True if this timeline sets values instantaneously and does not support interpolation between frames.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
propertyIds ArrayPropertyId
no setterinherited
rtti Rtti
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotIndex int
getter/setter pairoverride

Methods

apply(Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void
Applies this timeline to the skeleton.
inherited
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFrame(int frame, double time, SequenceMode mode, int index, double delay) → void
Sets the time, mode, index, and frame time for the specified frame.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited