setSkin2 method
Sets the skin used to look up attachments before looking in SkeletonData::getDefaultSkin(). If the skin is changed, updateCache() is called.
Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was no old skin, each slot's setup pose placeholder attachment is attached from the new skin.
After changing the skin, the visible attachments can be reset to those attached in the setup pose by calling setupPoseSlots(). Also, AnimationState::apply(Skeleton & ) is often called before the next time the skeleton is rendered so attachment keys in the current animation(s) can hide or show attachments from the new skin.
newSkin May be NULL.
Implementation
void setSkin2(Skin? newSkin) {
SpineBindings.bindings.spine_skeleton_set_skin_2(_ptr, newSkin?.nativePtr.cast() ?? Pointer.fromAddress(0));
}