updateCache method
void
updateCache()
Caches information about bones and constraints. Must be called if the active skin is modified or if bones, constraints, or weighted path attachments are added or removed.
Implementation
void updateCache() {
SpineBindings.bindings.spine_skeleton_update_cache(_ptr);
}