SkeletonClipping class

SkeletonClipping wrapper

Properties

clippedTriangles → ArrayUnsignedShort
no setter
clippedUVs → ArrayFloat
no setter
clippedVertices → ArrayFloat
no setter
hashCode → int
The hash code for this object.
no setterinherited
isClipping → bool
no setter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clipEnd(Slot slot) → void
clipEnd2() → void
clipStart(Skeleton skeleton, Slot slot, ClippingAttachment? clip) → int
clipTriangles(ArrayFloat vertices, ArrayUnsignedShort triangles, ArrayFloat uvs, int stride) → bool
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited