setAttachment method
Adds an attachment to the skin for the specified slot index and placeholder name. If the placeholder name already exists for the slot, the previous value is replaced.
Implementation
void setAttachment(int slotIndex, String placeholder, Attachment? attachment) {
SpineBindings.bindings.spine_skin_set_attachment(_ptr, slotIndex, placeholder.toNativeUtf8().cast<Char>(),
attachment?.nativePtr.cast() ?? Pointer.fromAddress(0));
}