Slider class

Slider wrapper

Inheritance

Constructors

Slider(SliderData data, Skeleton skeleton)
factory
Slider.fromPointer(Pointer<spine_slider_wrapper> _ptr)

Properties

active bool
no getterinherited
appliedPose SliderPose
The pose to use for rendering. If no constraints modify this pose, this is the same as getPose(). Otherwise it is a copy of getPose() modified by constraints.
no setterinherited
bone Bone
When set, the bone's transform property is used to set the slider's SliderPose::getTime().
getter/setter pair
data SliderData
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Returns false when this won't be updated by Skeleton::updateWorldTransform(Physics) because a skin is required and the active skin does not contain this item. See Skin::getBones(), Skin::getConstraints(), PosedData::getSkinRequired(), and Skeleton::updateCache().
no setterinherited
isPoseEqualToApplied bool
no setterinherited
isSourceActive bool
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
pose SliderPose
The unconstrained pose for this object, set by animations and application code.
no setterinherited
rtti Rtti
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

constrained() → void
Sets the applied pose to the constrained pose, in anticipation of the applied pose being modified by constraints.
inherited
copy(Skeleton skeleton) Slider
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetConstrained() → void
Sets the constrained pose to the unconstrained pose, as a starting point for constraints to be applied.
inherited
sort(Skeleton skeleton) → void
inherited
toString() String
A string representation of this object.
inherited
update(Skeleton skeleton, Physics physics) → void
Inherited from Update
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited