SliderData class

Stores the setup pose for a Slider

Inheritance
Implemented types

Constructors

SliderData(String name)
factory
SliderData.fromPointer(Pointer<spine_slider_data_wrapper> _ptr)

Properties

additive bool
When true, the animation is applied by adding it to the current pose rather than overwriting it.
getter/setter pair
animation Animation
The animation the slider will apply.
getter/setter pair
bone BoneData?
When set, the bone's transform property is used to set the slider's SliderPose::getTime().
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
local bool
When true and a bone is set, the bone's local transform property is read instead of its world transform.
getter/setter pair
loop bool
When true, the animation repeats after its duration, otherwise the last frame is used.
getter/setter pair
max double
When a bone is set, the maximum slider time for the bone property range, or 0 if nonessential data was not exported.
getter/setter pair
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
offset double
When a bone is set, the offset is added to the property.
getter/setter pair
property FromProperty?
When a bone is set, the specified transform property is used to set the slider's SliderPose::getTime().
getter/setter pair
rtti Rtti
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
When a bone is set, this is the scale of the property value in relation to the slider time.
getter/setter pair
setupPose SliderPose
The setup pose that most animations are relative to.
no setter
skinRequired bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited

Methods

createMethod(Skeleton skeleton) Constraint
Creates a slider instance.
override
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rttiStatic() Rtti
override