additive property

bool get additive

When true, the animation is applied by adding it to the current pose rather than overwriting it.

Implementation

bool get additive {
  final result = SpineBindings.bindings.spine_slider_data_get_additive(_ptr);
  return result;
}
set additive (bool value)

Implementation

set additive(bool value) {
  SpineBindings.bindings.spine_slider_data_set_additive(_ptr, value);
}