scale property
double
get
scale
When a bone is set, this is the scale of the property value in relation to the slider time.
Implementation
double get scale {
final result = SpineBindings.bindings.spine_slider_data_get_scale(_ptr);
return result;
}
set
scale
(double value)
Implementation
set scale(double value) {
SpineBindings.bindings.spine_slider_data_set_scale(_ptr, value);
}