SliderPose class
Stores a pose for a slider.
Constructors
- SliderPose()
-
factory
-
SliderPose.fromPointer(Pointer<
spine_slider_pose_wrapper> _ptr)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mix ↔ double
-
A percentage (unbounded) that controls the mix between the constrained and
unconstrained poses.
getter/setter pair
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ double
-
The time in SliderData::getAnimation() to apply the animation.
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
SliderPose pose) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited