constrained method

  1. @override
void constrained()
override

Sets the applied pose to the constrained pose, in anticipation of the applied pose being modified by constraints.

Implementation

@override
void constrained() {
  SpineBindings.bindings.spine_slot_constrained(_ptr);
}