SlotData class

Stores the setup pose for a Slot.

Inheritance

Constructors

SlotData(int index, String name, BoneData boneData)
factory
SlotData.fromPointer(Pointer<spine_slot_data_wrapper> _ptr)

Properties

attachmentName String
The name of the attachment that is visible for this slot in the setup pose, or empty if no attachment is visible.
getter/setter pair
blendMode BlendMode
The blend mode for drawing the slot's attachment.
getter/setter pair
boneData BoneData
The bone this slot belongs to.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
The Skeleton::getSlots() index for this slot.
no setter
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupPose SlotPose
The setup pose that most animations are relative to.
no setter
skinRequired bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited
visible bool
False if the slot was hidden in Spine and nonessential data was exported. Does not affect runtime rendering.
getter/setter pair

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited