SlotPose class

Stores a slot's pose.

Constructors

SlotPose()
factory
SlotPose.fromPointer(Pointer<spine_slot_pose_wrapper> _ptr)

Properties

attachment ↔ Attachment?
The current attachment for the slot, or null if the slot has no attachment.
getter/setter pair
color → Color
The color used to tint the slot's attachment. If a dark color is set, this is used as the light color for two color tinting.
no setter
darkColor → Color
The dark color used to tint the slot's attachment for two color tinting. The dark color's alpha is not used.
no setter
deform → ArrayFloat
Values to deform the slot's attachment. For an unweighted mesh, the entries are local positions for each vertex. For a weighted mesh, the entries are an offset for each vertex which will be added to the mesh's local vertex positions.
no setter
hasDarkColor ↔ bool
Returns true if this slot has a dark color.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceIndex ↔ int
The index of the texture region to display when the slot's attachment has a Sequence. -1 represents the Sequence::getSetupIndex().
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(SlotPose pose) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited