SpacingMode enum

SpacingMode enum

Inheritance
Available extensions

Values

length → const SpacingMode
const SpacingMode(0)
fixed → const SpacingMode
const SpacingMode(1)
percent → const SpacingMode
const SpacingMode(2)
proportional → const SpacingMode
const SpacingMode(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → SpacingMode

Constants

values → const List<SpacingMode>
A constant List of the values in this enum, in order of their declaration.