ToScaleX class

ToScaleX wrapper

Inheritance

Constructors

ToScaleX()
factory
ToScaleX.fromPointer(Pointer<spine_to_scale_x_wrapper> _ptr)

Properties

hashCode → int
The hash code for this object.
no setterinherited
max ↔ double
getter/setter pairinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
offset ↔ double
getter/setter pairinherited
rtti → Rtti
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
getter/setter pairinherited

Methods

apply(Skeleton skeleton, TransformConstraintPose pose, BonePose bone, double value, bool local, bool additive) → void
Applies the value to this property.
inherited
dispose() → void
mix(TransformConstraintPose pose) → double
Reads the mix for this property from the specified pose.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited