TrackEntry class
State for the playback of an animation
- Available extensions
Constructors
- TrackEntry()
-
factory
-
TrackEntry.fromPointer(Pointer<
spine_track_entry_wrapper> _ptr)
Properties
- additive ↔ bool
-
When true, timelines in this animation that support additive have their
values added to the setup or current pose values instead of replacing
them. Additive can be set for a new track entry only before
AnimationState::apply() is next called.
getter/setter pair
- alpha ↔ double
-
Values less than 1 mix this animation with the last skeleton pose.
Defaults to 1, which overwrites the last skeleton pose with this
animation.
getter/setter pair
- alphaAttachmentThreshold ↔ double
-
When the computed alpha is greater than alphaAttachmentThreshold,
attachment timelines are applied. The computed alpha includes alpha and
the interpolated mix percentage. Defaults to 0, so attachment timelines
are always applied.
getter/setter pair
- animation ↔ Animation
-
The animation to apply for this track entry.
getter/setter pair
- animationEnd ↔ double
-
The time in seconds for the last frame of this animation. Past this time,
non-looping animations hold the pose at this time while looping animations
will loop back to animationStart. Defaults to the animation duration.
getter/setter pair
- animationLast ↔ double
-
The time in seconds this animation was last applied. Some timelines use
this for one-time triggers. Eg, when this animation is applied, event
timelines will fire all events between the animation last time (exclusive)
and animation time (inclusive). Defaults to -1 to ensure triggers on frame
0 happen the first time this animation is applied.
getter/setter pair
- animationStart ↔ double
-
The time in seconds for the first frame of this animation, both initially
and after looping. Defaults to 0.
getter/setter pair
- animationState ↔ AnimationState?
-
The AnimationState this track entry belongs to. May be NULL if TrackEntry
is directly instantiated.
getter/setter pair
- animationTime → double
-
Uses the track time to compute animationTime, which is always between
animationStart and animationEnd. When trackTime is 0, animationTime is
equal to animationStart.
no setter
- delay ↔ double
-
Seconds to postpone playing the animation. Must be >= 0. When this track
entry is the current track entry, delay postpones incrementing the track
time. When this track entry is queued, delay is the time from the start of
the previous animation to when this track entry will become the current
track entry (ie when the previous track entry's track time >= this track
entry's delay).
getter/setter pair
- eventThreshold ↔ double
-
When the interpolated mix percentage is less than the event threshold,
event timelines for the animation being mixed out will be applied.
Defaults to 0, so event timelines are not applied for an animation being
mixed out.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
Returns true if at least one loop has been completed.
no setter
- isEmptyAnimation → bool
-
Returns true if this entry is for the empty animation.
no setter
- isNextReady → bool
-
Returns true if there is a next track entry that is ready to become the
current track entry during the next AnimationState::update(float)}
no setter
- loop ↔ bool
-
If true, the animation will repeat. If false, it will not, instead its
last frame is applied if played beyond its duration.
getter/setter pair
- mixAttachmentThreshold ↔ double
-
When the interpolated mix percentage is less than the attachment
threshold, attachment timelines for the animation being mixed out will be
applied. Defaults to 0, so attachment timelines are not applied for an
animation being mixed out.
getter/setter pair
- mixDrawOrderThreshold ↔ double
-
When the interpolated mix percentage is less than the draw order
threshold, draw order timelines for the animation being mixed out will be
applied. Defaults to 0, so draw order timelines are not applied for an
animation being mixed out.
getter/setter pair
- mixDuration → double
-
Seconds for mixing from the previous animation to this animation. Defaults
to the value provided by AnimationStateData based on the animation before
this animation (if any).
no setter
- mixingFrom → TrackEntry?
-
The track entry for the previous animation when mixing to this animation,
or NULL if no mixing is currently occurring. When mixing from multiple
animations, MixingFrom makes up a doubly linked list with MixingTo.
no setter
- mixingTo → TrackEntry?
-
The track entry for the next animation when mixing from this animation, or
NULL if no mixing is currently occurring. When mixing to multiple
animations, MixingTo makes up a doubly linked list with MixingFrom.
no setter
- mixInterpolation ↔ Interpolation
-
The interpolation to apply to the mix percentage (mix time / mix duration)
when mixing from the previous animation to this animation. Defaults to
linear.
getter/setter pair
- mixTime ↔ double
-
Seconds from 0 to the mix duration when mixing from the previous animation
to this animation. May be slightly more than mixDuration when the mix is
complete.
getter/setter pair
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setter
- next → TrackEntry?
-
The animation queued to start after this animation, or NULL.
no setter
- previous → TrackEntry?
-
no setter
-
rendererObject
→ Pointer<
Void> ? -
no setter
- reverse ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setMixDuration ← double
-
no getter
- shortestRotation ↔ bool
-
getter/setter pair
- timeScale ↔ double
-
Multiplier for the delta time when this track entry is updated, causing
time for this animation to pass slower or faster. Defaults to 1.
getter/setter pair
- trackComplete → double
-
no setter
- trackEnd ↔ double
-
The track time in seconds when this animation will be removed from the
track. Defaults to the highest possible float value, meaning the animation
will be applied until a new animation is set or the track is cleared. If
the track end time is reached, no other animations are queued for
playback, and mixing from any previous animations is complete, then the
properties keyed by the animation are set to the setup pose and the track
is cleared.
getter/setter pair
- trackIndex → int
-
The index of the track where this entry is either current or queued.
no setter
- trackTime ↔ double
-
The time in seconds this track entry has been the current track entry,
starting at 0 and increasing forever. Compare to getAnimationTime(), which
is always between animationStart and animationEnd.
getter/setter pair
- wasApplied → bool
-
Returns true if this track entry has been applied at least once.
no setter
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetRotationDirections(
) → void - Resets the rotation directions for mixing this entry's rotate timelines. This can be useful to avoid bones rotating the long way around when using alpha and starting animations on other tracks.
-
setListener(
AnimationStateListener? listener) → void -
Available on TrackEntry, provided by the TrackEntryExtensions extension
Set a listener for events from this track entry -
setMixDuration2(
double mixDuration, double delay) → void - Sets both mixDuration and delay.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited