animationEnd property

double get animationEnd

The time in seconds for the last frame of this animation. Past this time, non-looping animations hold the pose at this time while looping animations will loop back to animationStart. Defaults to the animation duration.

Implementation

double get animationEnd {
  final result = SpineBindings.bindings.spine_track_entry_get_animation_end(_ptr);
  return result;
}
set animationEnd (double value)

Implementation

set animationEnd(double value) {
  SpineBindings.bindings.spine_track_entry_set_animation_end(_ptr, value);
}