animationStart property

double get animationStart

The time in seconds for the first frame of this animation, both initially and after looping. Defaults to 0.

When setting the animation start time, animationLast can be set to the same value to avoid firing events from the start of the animation.

Implementation

double get animationStart {
  final result = SpineBindings.bindings.spine_track_entry_get_animation_start(_ptr);
  return result;
}
set animationStart (double value)

Implementation

set animationStart(double value) {
  SpineBindings.bindings.spine_track_entry_set_animation_start(_ptr, value);
}