eventThreshold property
double
get
eventThreshold
When the interpolated mix percentage is less than the event threshold, event timelines for the animation being mixed out will be applied. Defaults to 0, so event timelines are not applied for an animation being mixed out.
Implementation
double get eventThreshold {
final result = SpineBindings.bindings.spine_track_entry_get_event_threshold(_ptr);
return result;
}
set
eventThreshold
(double value)
Implementation
set eventThreshold(double value) {
SpineBindings.bindings.spine_track_entry_set_event_threshold(_ptr, value);
}