mixDrawOrderThreshold property

double get mixDrawOrderThreshold

When the interpolated mix percentage is less than the draw order threshold, draw order timelines for the animation being mixed out will be applied. Defaults to 0, so draw order timelines are not applied for an animation being mixed out.

Implementation

double get mixDrawOrderThreshold {
  final result = SpineBindings.bindings.spine_track_entry_get_mix_draw_order_threshold(_ptr);
  return result;
}
set mixDrawOrderThreshold (double value)

Implementation

set mixDrawOrderThreshold(double value) {
  SpineBindings.bindings.spine_track_entry_set_mix_draw_order_threshold(_ptr, value);
}