mixInterpolation property

Interpolation get mixInterpolation

The interpolation to apply to the mix percentage (mix time / mix duration) when mixing from the previous animation to this animation. Defaults to linear.

Implementation

Interpolation get mixInterpolation {
  final result = SpineBindings.bindings.spine_track_entry_get_mix_interpolation(_ptr);
  return Interpolation.fromPointer(result);
}
set mixInterpolation (Interpolation value)

Implementation

set mixInterpolation(Interpolation value) {
  SpineBindings.bindings.spine_track_entry_set_mix_interpolation(_ptr, value.nativePtr.cast());
}