trackTime property
double
get
trackTime
The time in seconds this track entry has been the current track entry, starting at 0 and increasing forever. Compare to getAnimationTime(), which is always between animationStart and animationEnd.
The track time can be set to start the animation at a time other than 0, without affecting looping. When doing so, animationLast can be set to the same value to avoid firing events from the start of the animation.
Implementation
double get trackTime {
final result = SpineBindings.bindings.spine_track_entry_get_track_time(_ptr);
return result;
}
set
trackTime
(double value)
Implementation
set trackTime(double value) {
SpineBindings.bindings.spine_track_entry_set_track_time(_ptr, value);
}