TransformConstraintData class

Stores the setup pose for a TransformConstraint.

See https://esotericsoftware.com/spine-transform-constraints Transform constraints in the Spine User Guide.

Inheritance
Implemented types

Properties

additive ↔ bool
Adds the source bone transform to the constrained bones instead of setting it absolutely.
getter/setter pair
bones → ArrayBoneData
The bones that will be modified by this transform constraint.
no setter
clamp ↔ bool
Prevents constrained bones from exceeding the ranged defined by offset and max.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localSource ↔ bool
Reads the source bone's local transform instead of its world transform.
getter/setter pair
localTarget ↔ bool
Sets the constrained bones' local transforms instead of their world transforms.
getter/setter pair
name → String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
offsetRotation ↔ double
An offset added to the constrained bone rotation.
getter/setter pair
offsetScaleX ↔ double
An offset added to the constrained bone scaleX.
getter/setter pair
offsetScaleY ↔ double
An offset added to the constrained bone scaleY.
getter/setter pair
offsetShearY ↔ double
An offset added to the constrained bone shearY.
getter/setter pair
offsetX ↔ double
An offset added to the constrained bone X translation.
getter/setter pair
offsetY ↔ double
An offset added to the constrained bone Y translation.
getter/setter pair
properties → ArrayFromProperty
The mapping of transform properties to other transform properties.
no setter
rtti → Rtti
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupPose → TransformConstraintPose
The setup pose that most animations are relative to.
no setter
skinRequired ↔ bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited
source ↔ BoneData
The bone whose world transform will be copied to the constrained bones.
getter/setter pair

Methods

createMethod(Skeleton skeleton) → Constraint
override
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

rttiStatic() → Rtti
override