TransformConstraintTimeline class

Changes a transform constraint's rotate, x, y, scaleX, scaleY, and shearY mix values.

Inheritance
Implemented types

Constructors

TransformConstraintTimeline(int frameCount, int bezierCount, int transformConstraintIndex)
factory
TransformConstraintTimeline.fromPointer(Pointer<spine_transform_constraint_timeline_wrapper> _ptr)

Properties

additive → bool
True if this timeline supports additive blending.
no setterinherited
constraintIndex ↔ int
getter/setter pairoverride
curves → ArrayFloat
no setterinherited
duration → double
no setterinherited
frameCount → int
no setterinherited
frameEntries → int
no setterinherited
frames → ArrayFloat
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
instant → bool
True if this timeline sets values instantaneously and does not support interpolation between frames.
no setterinherited
linear ← int
no getterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
propertyIds → ArrayPropertyId
no setterinherited
rtti → Rtti
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepped ← int
no getterinherited

Methods

apply(Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void
Applies this timeline to the skeleton.
inherited
dispose() → void
getBezierValue(double time, int frame, int valueOffset, int i) → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBezier(int bezier, int frame, double value, double time1, double value1, double cx1, double cy1, double cx2, double cy2, double time2, double value2) → void
inherited
setFrame(int frame, double time, double mixRotate, double mixX, double mixY, double mixScaleX, double mixScaleY, double mixShearY) → void
Sets the time, rotate mix, translate mix, scale mix, and shear mix for the specified frame.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited