VertexAttachment class abstract

An attachment with vertices that are transformed by one or more bones and can be deformed by SlotPose::getDeform().

Inheritance
Implementers

Properties

bones ArrayInt
The bones that affect the vertices. The entries are, for each vertex, the number of bones affecting the vertex followed by that many bone indices, which is Skeleton::getBones() index. Empty if this attachment has no weights.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
Gets a unique ID for this attachment.
no setter
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
refCount int
no setterinherited
rtti Rtti
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timelineAttachment Attachment?
getter/setter pairinherited
timelineSlots ArrayInt
getter/setter pairinherited
vertices ArrayFloat
The vertex positions in the bone's coordinate system. For a non-weighted attachment, the values are x,y pairs for each vertex. For a weighted attachment, the values are x,y,weight triplets for each bone affecting each vertex.
getter/setter pair
worldVerticesLength int
getter/setter pair

Methods

computeWorldVertices(Skeleton skeleton, Slot slot, int start, int count, ArrayFloat worldVertices, int offset, int stride) → void
copy() Attachment
inherited
copyTo(VertexAttachment other) → void
dereference() → void
inherited
isTimelineActive(ArraySlot slots, int slotIndex, bool appliedPose) bool
Returns true if the slotIndex or any getTimelineSlots() have an attachment whose getTimelineAttachment() is this attachment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reference() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited