bones property

ArrayInt get bones

The bones that affect the vertices. The entries are, for each vertex, the number of bones affecting the vertex followed by that many bone indices, which is Skeleton::getBones() index. Empty if this attachment has no weights.

Implementation

ArrayInt get bones {
  final result = SpineBindings.bindings.spine_vertex_attachment_get_bones(_ptr);
  return ArrayInt.fromPointer(result);
}
set bones (ArrayInt value)

Implementation

set bones(ArrayInt value) {
  SpineBindings.bindings.spine_vertex_attachment_set_bones(_ptr, value.nativePtr.cast());
}