spine_dart
library
Classes
AlphaTimeline
AlphaTimeline wrapper
Animation
Stores a list of timelines to animate a skeleton's pose over time.
AnimationState
Applies animations over time, queues animations for later playback, mixes
(crossfading) between animations, and applies multiple animations on top of
each other (layering).
AnimationStateData
Stores mix (crossfade) durations to be applied when AnimationState
animations are changed on the same track.
AnimationStateEventManager
Manager for animation state event listeners
ArrayAnimation
ArrayAnimation wrapper
ArrayAtlasPage
ArrayAtlasPage wrapper
ArrayAtlasRegion
ArrayAtlasRegion wrapper
ArrayAttachment
ArrayAttachment wrapper
ArrayBone
ArrayBone wrapper
ArrayBoneData
ArrayBoneData wrapper
ArrayBonePose
ArrayBonePose wrapper
ArrayBoundingBoxAttachment
ArrayBoundingBoxAttachment wrapper
ArrayConstraint
ArrayConstraint wrapper
ArrayConstraintData
ArrayConstraintData wrapper
ArrayEvent
ArrayEvent wrapper
ArrayEventData
ArrayEventData wrapper
ArrayFloat
ArrayFloat wrapper
ArrayFromProperty
ArrayFromProperty wrapper
ArrayInt
ArrayInt wrapper
ArrayPhysicsConstraint
ArrayPhysicsConstraint wrapper
ArrayPolygon
ArrayPolygon wrapper
ArrayPropertyId
ArrayPropertyId wrapper
ArraySkin
ArraySkin wrapper
ArraySlot
ArraySlot wrapper
ArraySlotData
ArraySlotData wrapper
ArrayTextureRegion
ArrayTextureRegion wrapper
ArrayTimeline
ArrayTimeline wrapper
ArrayToProperty
ArrayToProperty wrapper
ArrayTrackEntry
ArrayTrackEntry wrapper
ArrayUnsignedShort
ArrayUnsignedShort wrapper
ArrayUpdate
ArrayUpdate wrapper
Atlas
Atlas wrapper
AtlasAttachmentLoader
An AttachmentLoader that configures attachments using texture regions from
an Atlas.
AtlasPage
AtlasPage wrapper
AtlasRegion
AtlasRegion wrapper
Attachment
The base class for all attachments. Multiple Skeleton instances, slots, or
skins can use the same attachments.
AttachmentLoader
AttachmentLoader wrapper
AttachmentTimeline
AttachmentTimeline wrapper
Bone
A node in a skeleton's hierarchy with a transform that affects its children
and their attachments. A bone has a number of poses: - getData(): The setup
pose data. - getPose(): The unconstrained local pose. Set by animations and
application code. - getAppliedPose(): The local pose to use for rendering.
Possibly modified by constraints. - World transform: the local pose combined
with the parent world transform. Computed on a pose by
BonePose::updateWorldTransform(Skeleton) and
Skeleton::updateWorldTransform(Physics).
BoneData
BoneData wrapper
BoneLocal
Stores a bone's local pose.
BonePose
The applied local pose and world transform for a bone. This is the bone's
unconstrained pose with constraints applied and the world transform computed
by Skeleton::updateWorldTransform(Physics) and
updateWorldTransform(Skeleton).
BoneTimeline
An interface for timelines which change the property of a bone.
BoneTimeline1
Base class for timelines that animate a single bone property.
BoneTimeline2
Base class for timelines that animate two bone properties.
BoundingBoxAttachment
Attachment that has a polygon for bounds checking.
Bounds
Represents a bounding box with position and dimensions
ClippingAttachment
ClippingAttachment wrapper
Color
Color wrapper
Constraint
Constraint wrapper
ConstraintData
ConstraintData wrapper
ConstraintTimeline
An interface for timelines which change the property of a constraint.
ConstraintTimeline1
The base class for timelines that change 1 constraint property with a curve.
CurveTimeline
Base class for frames that use an interpolation bezier curve.
CurveTimeline1
The base class for a CurveTimeline that sets one property.
DeformTimeline
Changes a slot's deform to deform a VertexAttachment.
DrawOrder
Stores the skeleton's draw order, which is the order that each slot's
attachment is rendered.
DrawOrderFolderTimeline
Changes a subset of the Skeleton::getDrawOrder() draw order.
DrawOrderTimeline
Changes the Skeleton::getDrawOrder().
Event
Fired by EventTimeline when specific animation times are reached.
EventData
Stores the setup pose values for an Event.
EventQueueEntry
EventQueueEntry wrapper
EventTimeline
Fires an Event when specific animation times are reached.
FromProperty
Source property for a TransformConstraint.
FromRotate
FromRotate wrapper
FromScaleX
FromScaleX wrapper
FromScaleY
FromScaleY wrapper
FromShearY
FromShearY wrapper
FromX
FromX wrapper
FromY
FromY wrapper
IkConstraint
IkConstraint wrapper
IkConstraintBase
Non-exported base class that inherits from the template
IkConstraintData
IkConstraintData wrapper
IkConstraintPose
Stores a pose for an IK constraint.
IkConstraintTimeline
Changes an IK constraint's mix, softness, bend direction, stretch, and
compress values.
InheritTimeline
Changes a bone's inherit mode.
Interpolation
Takes a linear value in the range 0-1 and outputs a usually non-linear,
interpolated value.
LinkedMesh
LinkedMesh wrapper
MeshAttachment
Attachment that displays a texture region using a mesh.
PathAttachment
PathAttachment wrapper
PathConstraint
PathConstraint wrapper
PathConstraintBase
Adjusts the rotation, translation, and scale of the constrained bones so
they follow a PathAttachment.
PathConstraintData
Stores the setup pose for a PathConstraint.
PathConstraintMixTimeline
Changes a path constraint's rotate, x, and y mix values.
PathConstraintPose
Stores a pose for a path constraint.
PathConstraintPositionTimeline
Changes a path constraint's position.
PathConstraintSpacingTimeline
Changes a path constraint's spacing.
PhysicsConstraint
PhysicsConstraint wrapper
PhysicsConstraintBase
Applies physics to a bone.
PhysicsConstraintDampingTimeline
Changes a physics constraint's damping.
PhysicsConstraintData
Stores the setup pose for a PhysicsConstraint.
PhysicsConstraintGravityTimeline
Changes a physics constraint's gravity.
PhysicsConstraintInertiaTimeline
Changes a physics constraint's inertia.
PhysicsConstraintMassTimeline
Changes a physics constraint's mass inverse. The timeline values are not
inverted.
PhysicsConstraintMixTimeline
Changes a physics constraint's mix.
PhysicsConstraintPose
Stores a pose for a physics constraint.
PhysicsConstraintResetTimeline
Resets a physics constraint when specific animation times are reached.
PhysicsConstraintStrengthTimeline
Changes a physics constraint's strength.
PhysicsConstraintTimeline
The base class for most PhysicsConstraint timelines.
PhysicsConstraintWindTimeline
Changes a physics constraint's wind.
PointAttachment
An attachment which is a single point and a rotation. This can be used to
spawn projectiles, particles, etc. A bone can be used in similar ways, but a
PointAttachment is slightly less expensive to compute and can be hidden,
shown, and placed in a skin.
Polygon
Polygon wrapper
Posed
Base interface for posed objects.
PosedActive
A posed object that may be active or inactive.
PosedData
PosedData wrapper
RegionAttachment
Attachment that displays a texture region.
RenderCommand
RenderCommand wrapper
Rgb2Timeline
Changes RGB for a slot's light and dark colors for two color tinting.
Rgba2Timeline
Changes a slot's light and dark colors for two color tinting.
RgbaTimeline
Changes a slot's color.
RgbTimeline
Changes RGB for a slot's color.
RotateTimeline
Changes a bone's local rotation.
Rtti
Rtti wrapper
ScaleTimeline
Changes a bone's local scaleX and scaleY.
ScaleXTimeline
Changes a bone's local scaleX.
ScaleYTimeline
Changes a bone's local scaleY.
Sequence
Holds texture regions, UVs, and vertex offsets for rendering a region or
mesh attachment. Regions must be populated and update() called before use.
SequenceTimeline
Changes the sequence index for an attachment's Sequence.
ShearTimeline
Changes a bone's local shearX and shearY.
ShearXTimeline
Changes a bone's local shearX.
ShearYTimeline
Changes a bone's local shearY.
Skeleton
Stores bones and slots to be posed by animations and application code.
Multiple skeleton instances can share the same SkeletonData, including
animations, attachments, and skins.
SkeletonBinary
SkeletonBinary wrapper
SkeletonBounds
Collects each BoundingBoxAttachment that is visible and computes the world
vertices for its polygon. The polygon vertices are provided along with
convenience methods for doing hit detection.
SkeletonClipping
SkeletonClipping wrapper
SkeletonData
Stores the setup pose and all of the stateless data for a skeleton.
SkeletonDrawable
Convenient drawable that combines skeleton, animation state, and rendering
SkeletonJson
SkeletonJson wrapper
SkeletonRenderer
SkeletonRenderer wrapper
Skin
Stores attachments by slot index and placeholder name. Multiple Skeleton
instances can use the same skins. See SkeletonData::getDefaultSkin,
Skeleton::getSkin, and http://esotericsoftware.com/spine-runtime-skins in
the Spine Runtimes Guide.
SkinEntry
Represents an entry in a skin
Slider
Slider wrapper
SliderBase
Applies an animation based on either the slider's SliderPose::getTime() or a
bone's transform property.
SliderData
Stores the setup pose for a Slider
SliderMixTimeline
Changes a slider's mix.
SliderPose
Stores a pose for a slider.
SliderTimeline
Changes a slider's time.
Slot
Organizes attachments for Skeleton drawOrder purposes and provide a place to
store state for an attachment.
SlotCurveTimeline
Base class for slot timelines that use curves.
SlotData
Stores the setup pose for a Slot.
SlotPose
Stores a slot's pose.
SlotTimeline
An interface for timelines which change the property of a slot.
spine_alpha_timeline_wrapper
mbstate_t is an opaque object to keep conversion state, during multibyte
stream conversions. The content must not be referenced by user programs.
Forward declarations for all non-enum types
spine_animation_state_data_wrapper
spine_animation_state_events_wrapper
spine_animation_state_wrapper
spine_animation_wrapper
spine_array_animation_wrapper
spine_array_atlas_page_wrapper
spine_array_atlas_region_wrapper
spine_array_attachment_wrapper
spine_array_bone_data_wrapper
spine_array_bone_pose_wrapper
spine_array_bone_wrapper
spine_array_bounding_box_attachment_wrapper
spine_array_constraint_data_wrapper
spine_array_constraint_wrapper
spine_array_event_data_wrapper
spine_array_event_wrapper
spine_array_float_wrapper
spine_array_from_property_wrapper
spine_array_int_wrapper
spine_array_physics_constraint_wrapper
spine_array_polygon_wrapper
spine_array_property_id_wrapper
spine_array_skin_wrapper
spine_array_slot_data_wrapper
spine_array_slot_wrapper
spine_array_texture_region_wrapper
spine_array_timeline_wrapper
spine_array_to_property_wrapper
spine_array_track_entry_wrapper
spine_array_unsigned_short_wrapper
spine_array_update_wrapper
spine_atlas_attachment_loader_wrapper
spine_atlas_page_wrapper
spine_atlas_region_wrapper
spine_atlas_result_wrapper
Custom types for spine-c-new (not generated)
spine_atlas_wrapper
spine_attachment_loader_wrapper
spine_attachment_timeline_wrapper
spine_attachment_type
spine_attachment_wrapper
spine_blend_mode
spine_bone_data_wrapper
spine_bone_local_wrapper
spine_bone_pose_wrapper
spine_bone_timeline1_wrapper
spine_bone_timeline2_wrapper
spine_bone_timeline_wrapper
spine_bone_wrapper
spine_bounding_box_attachment_wrapper
spine_clipping_attachment_wrapper
spine_color_wrapper
spine_constraint_data_wrapper
spine_constraint_timeline1_wrapper
spine_constraint_timeline_wrapper
spine_constraint_wrapper
spine_curve_timeline1_wrapper
spine_curve_timeline_wrapper
spine_deform_timeline_wrapper
spine_draw_order_folder_timeline_wrapper
spine_draw_order_timeline_wrapper
spine_draw_order_wrapper
spine_event_data_wrapper
spine_event_queue_entry_wrapper
spine_event_timeline_wrapper
spine_event_type
spine_event_wrapper
spine_format
spine_from_property_wrapper
spine_from_rotate_wrapper
spine_from_scale_x_wrapper
spine_from_scale_y_wrapper
spine_from_shear_y_wrapper
spine_from_x_wrapper
spine_from_y_wrapper
spine_ik_constraint_base_wrapper
spine_ik_constraint_data_wrapper
spine_ik_constraint_pose_wrapper
spine_ik_constraint_timeline_wrapper
spine_ik_constraint_wrapper
spine_inherit
spine_inherit_timeline_wrapper
spine_interpolation_wrapper
spine_linked_mesh_wrapper
spine_mesh_attachment_wrapper
spine_mix_from
spine_path_attachment_wrapper
spine_path_constraint_base_wrapper
spine_path_constraint_data_wrapper
spine_path_constraint_mix_timeline_wrapper
spine_path_constraint_pose_wrapper
spine_path_constraint_position_timeline_wrapper
spine_path_constraint_spacing_timeline_wrapper
spine_path_constraint_wrapper
spine_physics
spine_physics_constraint_base_wrapper
spine_physics_constraint_damping_timeline_wrapper
spine_physics_constraint_data_wrapper
spine_physics_constraint_gravity_timeline_wrapper
spine_physics_constraint_inertia_timeline_wrapper
spine_physics_constraint_mass_timeline_wrapper
spine_physics_constraint_mix_timeline_wrapper
spine_physics_constraint_pose_wrapper
spine_physics_constraint_reset_timeline_wrapper
spine_physics_constraint_strength_timeline_wrapper
spine_physics_constraint_timeline_wrapper
spine_physics_constraint_wind_timeline_wrapper
spine_physics_constraint_wrapper
spine_point_attachment_wrapper
spine_polygon_wrapper
spine_posed_active_wrapper
spine_posed_data_wrapper
spine_posed_wrapper
spine_position_mode
spine_property
spine_region_attachment_wrapper
spine_render_command_wrapper
spine_rgb2_timeline_wrapper
spine_rgb_timeline_wrapper
spine_rgba2_timeline_wrapper
spine_rgba_timeline_wrapper
spine_rotate_mode
spine_rotate_timeline_wrapper
spine_rtti_wrapper
spine_scale_timeline_wrapper
spine_scale_x_timeline_wrapper
spine_scale_y_mode
spine_scale_y_timeline_wrapper
spine_sequence_mode
spine_sequence_timeline_wrapper
spine_sequence_wrapper
spine_shear_timeline_wrapper
spine_shear_x_timeline_wrapper
spine_shear_y_timeline_wrapper
spine_skeleton_binary_wrapper
spine_skeleton_bounds_wrapper
spine_skeleton_clipping_wrapper
spine_skeleton_data_result_wrapper
spine_skeleton_data_wrapper
spine_skeleton_drawable_wrapper
spine_skeleton_json_wrapper
spine_skeleton_renderer_wrapper
spine_skeleton_wrapper
spine_skin_entries_wrapper
spine_skin_entry_wrapper
spine_skin_wrapper
spine_slider_base_wrapper
spine_slider_data_wrapper
spine_slider_mix_timeline_wrapper
spine_slider_pose_wrapper
spine_slider_timeline_wrapper
spine_slider_wrapper
spine_slot_curve_timeline_wrapper
spine_slot_data_wrapper
spine_slot_pose_wrapper
spine_slot_timeline_wrapper
spine_slot_wrapper
spine_spacing_mode
spine_texture_filter
spine_texture_loader_wrapper
spine_texture_region_wrapper
spine_texture_wrap
spine_timeline_wrapper
spine_to_property_wrapper
spine_to_rotate_wrapper
spine_to_scale_x_wrapper
spine_to_scale_y_wrapper
spine_to_shear_y_wrapper
spine_to_x_wrapper
spine_to_y_wrapper
spine_track_entry_wrapper
spine_transform_constraint_base_wrapper
spine_transform_constraint_data_wrapper
spine_transform_constraint_pose_wrapper
spine_transform_constraint_timeline_wrapper
spine_transform_constraint_wrapper
spine_translate_timeline_wrapper
spine_translate_x_timeline_wrapper
spine_translate_y_timeline_wrapper
spine_update_wrapper
spine_vertex_attachment_wrapper
SpineBindings
Global bindings instance for all spine-flutter classes
SpineDartBindings
Bindings for Spine C headers.
TextureRegion
TextureRegion wrapper
Timeline
The base class for all timelines.
ToProperty
Constrained property for a TransformConstraint.
ToRotate
ToRotate wrapper
ToScaleX
ToScaleX wrapper
ToScaleY
ToScaleY wrapper
ToShearY
ToShearY wrapper
ToX
ToX wrapper
ToY
ToY wrapper
TrackEntry
State for the playback of an animation
TransformConstraint
Adjusts the world transform of the constrained bones to match that of the
source bone.
TransformConstraintBase
Non-exported base class that inherits from the template
TransformConstraintData
Stores the setup pose for a TransformConstraint.
TransformConstraintPose
Stores a pose for a transform constraint.
TransformConstraintTimeline
Changes a transform constraint's rotate, x, y, scaleX, scaleY, and shearY
mix values.
TranslateTimeline
Changes a bone's local X and Y translation.
TranslateXTimeline
Changes a bone's local X translation.
TranslateYTimeline
Changes a bone's local Y translation.
Update
The interface for items updated by Skeleton::updateWorldTransform().
Vector
VertexAttachment
An attachment with vertices that are transformed by one or more bones and
can be deformed by SlotPose::getDeform().
Typedefs
AnimationStateListener
= void Function(EventType type , TrackEntry entry , Event ? event )
Event listener callback for animation state events
Dartspine_animation_state_listenerFunction
= void Function(spine_animation_state state , int type , spine_track_entry entry , spine_event event , Pointer<Void > user_data )
Dartspine_texture_loader_unload_funcFunction
= void Function(Pointer<Void > texture )
spine_alpha_timeline
= Pointer<spine_alpha_timeline_wrapper >
spine_animation
= Pointer<spine_animation_wrapper >
Forward declarations for all non-enum types
spine_animation_state
= Pointer<spine_animation_state_wrapper >
Forward declarations for all non-enum types
spine_animation_state_data
= Pointer<spine_animation_state_data_wrapper >
Forward declarations for all non-enum types
spine_animation_state_events
= Pointer<spine_animation_state_events_wrapper >
Custom types for spine-c-new (not generated)
spine_animation_state_listener
= Pointer<NativeFunction<spine_animation_state_listenerFunction > >
Event listener functions
spine_animation_state_listenerFunction
= Void Function(spine_animation_state state , Int32 type , spine_track_entry entry , spine_event event , Pointer<Void > user_data )
spine_array_animation
= Pointer<spine_array_animation_wrapper >
spine_array_atlas_page
= Pointer<spine_array_atlas_page_wrapper >
spine_array_atlas_region
= Pointer<spine_array_atlas_region_wrapper >
spine_array_attachment
= Pointer<spine_array_attachment_wrapper >
spine_array_bone
= Pointer<spine_array_bone_wrapper >
spine_array_bone_data
= Pointer<spine_array_bone_data_wrapper >
spine_array_bone_pose
= Pointer<spine_array_bone_pose_wrapper >
spine_array_bounding_box_attachment
= Pointer<spine_array_bounding_box_attachment_wrapper >
spine_array_constraint
= Pointer<spine_array_constraint_wrapper >
spine_array_constraint_data
= Pointer<spine_array_constraint_data_wrapper >
spine_array_event
= Pointer<spine_array_event_wrapper >
spine_array_event_data
= Pointer<spine_array_event_data_wrapper >
spine_array_float
= Pointer<spine_array_float_wrapper >
spine_array_from_property
= Pointer<spine_array_from_property_wrapper >
spine_array_int
= Pointer<spine_array_int_wrapper >
spine_array_physics_constraint
= Pointer<spine_array_physics_constraint_wrapper >
spine_array_polygon
= Pointer<spine_array_polygon_wrapper >
spine_array_property_id
= Pointer<spine_array_property_id_wrapper >
spine_array_skin
= Pointer<spine_array_skin_wrapper >
spine_array_slot
= Pointer<spine_array_slot_wrapper >
spine_array_slot_data
= Pointer<spine_array_slot_data_wrapper >
spine_array_texture_region
= Pointer<spine_array_texture_region_wrapper >
spine_array_timeline
= Pointer<spine_array_timeline_wrapper >
spine_array_to_property
= Pointer<spine_array_to_property_wrapper >
spine_array_track_entry
= Pointer<spine_array_track_entry_wrapper >
spine_array_unsigned_short
= Pointer<spine_array_unsigned_short_wrapper >
spine_array_update
= Pointer<spine_array_update_wrapper >
spine_atlas
= Pointer<spine_atlas_wrapper >
Forward declarations for all non-enum types
spine_atlas_attachment_loader
= Pointer<spine_atlas_attachment_loader_wrapper >
spine_atlas_page
= Pointer<spine_atlas_page_wrapper >
Forward declarations for all non-enum types
spine_atlas_region
= Pointer<spine_atlas_region_wrapper >
Forward declarations for all non-enum types
spine_atlas_result
= Pointer<spine_atlas_result_wrapper >
Custom types for spine-c-new (not generated)
spine_attachment
= Pointer<spine_attachment_wrapper >
Forward declarations for all non-enum types
spine_attachment_loader
= Pointer<spine_attachment_loader_wrapper >
Forward declarations for all non-enum types
spine_attachment_timeline
= Pointer<spine_attachment_timeline_wrapper >
Forward declarations for all non-enum types
spine_bone
= Pointer<spine_bone_wrapper >
Forward declarations for all non-enum types
spine_bone_data
= Pointer<spine_bone_data_wrapper >
Forward declarations for all non-enum types
spine_bone_local
= Pointer<spine_bone_local_wrapper >
Forward declarations for all non-enum types
spine_bone_pose
= Pointer<spine_bone_pose_wrapper >
Forward declarations for all non-enum types
spine_bone_timeline
= Pointer<spine_bone_timeline_wrapper >
Forward declarations for all non-enum types
spine_bone_timeline1
= Pointer<spine_bone_timeline1_wrapper >
Forward declarations for all non-enum types
spine_bone_timeline2
= Pointer<spine_bone_timeline2_wrapper >
Forward declarations for all non-enum types
spine_bounding_box_attachment
= Pointer<spine_bounding_box_attachment_wrapper >
Forward declarations for all non-enum types
spine_clipping_attachment
= Pointer<spine_clipping_attachment_wrapper >
Forward declarations for all non-enum types
spine_color
= Pointer<spine_color_wrapper >
Forward declarations for all non-enum types
spine_constraint
= Pointer<spine_constraint_wrapper >
Forward declarations for all non-enum types
spine_constraint_data
= Pointer<spine_constraint_data_wrapper >
Forward declarations for all non-enum types
spine_constraint_timeline
= Pointer<spine_constraint_timeline_wrapper >
Forward declarations for all non-enum types
spine_constraint_timeline1
= Pointer<spine_constraint_timeline1_wrapper >
Forward declarations for all non-enum types
spine_curve_timeline
= Pointer<spine_curve_timeline_wrapper >
Forward declarations for all non-enum types
spine_curve_timeline1
= Pointer<spine_curve_timeline1_wrapper >
Forward declarations for all non-enum types
spine_deform_timeline
= Pointer<spine_deform_timeline_wrapper >
spine_draw_order
= Pointer<spine_draw_order_wrapper >
Forward declarations for all non-enum types
spine_draw_order_folder_timeline
= Pointer<spine_draw_order_folder_timeline_wrapper >
Forward declarations for all non-enum types
spine_draw_order_timeline
= Pointer<spine_draw_order_timeline_wrapper >
Forward declarations for all non-enum types
spine_event
= Pointer<spine_event_wrapper >
Forward declarations for all non-enum types
spine_event_data
= Pointer<spine_event_data_wrapper >
Forward declarations for all non-enum types
spine_event_queue_entry
= Pointer<spine_event_queue_entry_wrapper >
Forward declarations for all non-enum types
spine_event_timeline
= Pointer<spine_event_timeline_wrapper >
Forward declarations for all non-enum types
spine_from_property
= Pointer<spine_from_property_wrapper >
Forward declarations for all non-enum types
spine_from_rotate
= Pointer<spine_from_rotate_wrapper >
Forward declarations for all non-enum types
spine_from_scale_x
= Pointer<spine_from_scale_x_wrapper >
Forward declarations for all non-enum types
spine_from_scale_y
= Pointer<spine_from_scale_y_wrapper >
Forward declarations for all non-enum types
spine_from_shear_y
= Pointer<spine_from_shear_y_wrapper >
Forward declarations for all non-enum types
spine_from_x
= Pointer<spine_from_x_wrapper >
Forward declarations for all non-enum types
spine_from_y
= Pointer<spine_from_y_wrapper >
Forward declarations for all non-enum types
spine_ik_constraint
= Pointer<spine_ik_constraint_wrapper >
spine_ik_constraint_base
= Pointer<spine_ik_constraint_base_wrapper >
Forward declarations for all non-enum types
spine_ik_constraint_data
= Pointer<spine_ik_constraint_data_wrapper >
Forward declarations for all non-enum types
spine_ik_constraint_pose
= Pointer<spine_ik_constraint_pose_wrapper >
Forward declarations for all non-enum types
spine_ik_constraint_timeline
= Pointer<spine_ik_constraint_timeline_wrapper >
Forward declarations for all non-enum types
spine_inherit_timeline
= Pointer<spine_inherit_timeline_wrapper >
Forward declarations for all non-enum types
spine_interpolation
= Pointer<spine_interpolation_wrapper >
Forward declarations for all non-enum types
spine_linked_mesh
= Pointer<spine_linked_mesh_wrapper >
Forward declarations for all non-enum types
spine_mesh_attachment
= Pointer<spine_mesh_attachment_wrapper >
Forward declarations for all non-enum types
spine_path_attachment
= Pointer<spine_path_attachment_wrapper >
Forward declarations for all non-enum types
spine_path_constraint
= Pointer<spine_path_constraint_wrapper >
spine_path_constraint_base
= Pointer<spine_path_constraint_base_wrapper >
Forward declarations for all non-enum types
spine_path_constraint_data
= Pointer<spine_path_constraint_data_wrapper >
Forward declarations for all non-enum types
spine_path_constraint_mix_timeline
= Pointer<spine_path_constraint_mix_timeline_wrapper >
Forward declarations for all non-enum types
spine_path_constraint_pose
= Pointer<spine_path_constraint_pose_wrapper >
Forward declarations for all non-enum types
spine_path_constraint_position_timeline
= Pointer<spine_path_constraint_position_timeline_wrapper >
Forward declarations for all non-enum types
spine_path_constraint_spacing_timeline
= Pointer<spine_path_constraint_spacing_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint
= Pointer<spine_physics_constraint_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_base
= Pointer<spine_physics_constraint_base_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_damping_timeline
= Pointer<spine_physics_constraint_damping_timeline_wrapper >
spine_physics_constraint_data
= Pointer<spine_physics_constraint_data_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_gravity_timeline
= Pointer<spine_physics_constraint_gravity_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_inertia_timeline
= Pointer<spine_physics_constraint_inertia_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_mass_timeline
= Pointer<spine_physics_constraint_mass_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_mix_timeline
= Pointer<spine_physics_constraint_mix_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_pose
= Pointer<spine_physics_constraint_pose_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_reset_timeline
= Pointer<spine_physics_constraint_reset_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_strength_timeline
= Pointer<spine_physics_constraint_strength_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_timeline
= Pointer<spine_physics_constraint_timeline_wrapper >
Forward declarations for all non-enum types
spine_physics_constraint_wind_timeline
= Pointer<spine_physics_constraint_wind_timeline_wrapper >
Forward declarations for all non-enum types
spine_point_attachment
= Pointer<spine_point_attachment_wrapper >
Forward declarations for all non-enum types
spine_polygon
= Pointer<spine_polygon_wrapper >
Forward declarations for all non-enum types
spine_posed
= Pointer<spine_posed_wrapper >
Forward declarations for all non-enum types
spine_posed_active
= Pointer<spine_posed_active_wrapper >
Forward declarations for all non-enum types
spine_posed_data
= Pointer<spine_posed_data_wrapper >
Forward declarations for all non-enum types
spine_region_attachment
= Pointer<spine_region_attachment_wrapper >
Forward declarations for all non-enum types
spine_render_command
= Pointer<spine_render_command_wrapper >
Forward declarations for all non-enum types
spine_rgb2_timeline
= Pointer<spine_rgb2_timeline_wrapper >
Forward declarations for all non-enum types
spine_rgb_timeline
= Pointer<spine_rgb_timeline_wrapper >
Forward declarations for all non-enum types
spine_rgba2_timeline
= Pointer<spine_rgba2_timeline_wrapper >
Forward declarations for all non-enum types
spine_rgba_timeline
= Pointer<spine_rgba_timeline_wrapper >
Forward declarations for all non-enum types
spine_rotate_timeline
= Pointer<spine_rotate_timeline_wrapper >
Forward declarations for all non-enum types
spine_rtti
= Pointer<spine_rtti_wrapper >
Forward declarations for all non-enum types
spine_scale_timeline
= Pointer<spine_scale_timeline_wrapper >
Forward declarations for all non-enum types
spine_scale_x_timeline
= Pointer<spine_scale_x_timeline_wrapper >
Forward declarations for all non-enum types
spine_scale_y_timeline
= Pointer<spine_scale_y_timeline_wrapper >
Forward declarations for all non-enum types
spine_sequence
= Pointer<spine_sequence_wrapper >
Forward declarations for all non-enum types
spine_sequence_timeline
= Pointer<spine_sequence_timeline_wrapper >
Forward declarations for all non-enum types
spine_shear_timeline
= Pointer<spine_shear_timeline_wrapper >
Forward declarations for all non-enum types
spine_shear_x_timeline
= Pointer<spine_shear_x_timeline_wrapper >
Forward declarations for all non-enum types
spine_shear_y_timeline
= Pointer<spine_shear_y_timeline_wrapper >
Forward declarations for all non-enum types
spine_skeleton
= Pointer<spine_skeleton_wrapper >
Forward declarations for all non-enum types
spine_skeleton_binary
= Pointer<spine_skeleton_binary_wrapper >
Forward declarations for all non-enum types
spine_skeleton_bounds
= Pointer<spine_skeleton_bounds_wrapper >
Forward declarations for all non-enum types
spine_skeleton_clipping
= Pointer<spine_skeleton_clipping_wrapper >
Forward declarations for all non-enum types
spine_skeleton_data
= Pointer<spine_skeleton_data_wrapper >
Forward declarations for all non-enum types
spine_skeleton_data_result
= Pointer<spine_skeleton_data_result_wrapper >
Custom types for spine-c-new (not generated)
spine_skeleton_drawable
= Pointer<spine_skeleton_drawable_wrapper >
Custom types for spine-c-new (not generated)
spine_skeleton_json
= Pointer<spine_skeleton_json_wrapper >
Forward declarations for all non-enum types
spine_skeleton_renderer
= Pointer<spine_skeleton_renderer_wrapper >
Forward declarations for all non-enum types
spine_skin
= Pointer<spine_skin_wrapper >
Forward declarations for all non-enum types
spine_skin_entries
= Pointer<spine_skin_entries_wrapper >
Custom types for spine-c-new (not generated)
spine_skin_entry
= Pointer<spine_skin_entry_wrapper >
Custom types for spine-c-new (not generated)
spine_slider
= Pointer<spine_slider_wrapper >
spine_slider_base
= Pointer<spine_slider_base_wrapper >
Forward declarations for all non-enum types
spine_slider_data
= Pointer<spine_slider_data_wrapper >
Forward declarations for all non-enum types
spine_slider_mix_timeline
= Pointer<spine_slider_mix_timeline_wrapper >
Forward declarations for all non-enum types
spine_slider_pose
= Pointer<spine_slider_pose_wrapper >
Forward declarations for all non-enum types
spine_slider_timeline
= Pointer<spine_slider_timeline_wrapper >
Forward declarations for all non-enum types
spine_slot
= Pointer<spine_slot_wrapper >
Forward declarations for all non-enum types
spine_slot_curve_timeline
= Pointer<spine_slot_curve_timeline_wrapper >
Forward declarations for all non-enum types
spine_slot_data
= Pointer<spine_slot_data_wrapper >
Forward declarations for all non-enum types
spine_slot_pose
= Pointer<spine_slot_pose_wrapper >
Forward declarations for all non-enum types
spine_slot_timeline
= Pointer<spine_slot_timeline_wrapper >
Forward declarations for all non-enum types
spine_texture_loader_load_func
= Pointer<NativeFunction<spine_texture_loader_load_funcFunction > >
Texture loader callbacks
spine_texture_loader_load_funcFunction
= Pointer<Void > Function(Pointer<Char > path )
spine_texture_loader_unload_func
= Pointer<NativeFunction<spine_texture_loader_unload_funcFunction > >
spine_texture_loader_unload_funcFunction
= Void Function(Pointer<Void > texture )
spine_texture_region
= Pointer<spine_texture_region_wrapper >
Forward declarations for all non-enum types
spine_timeline
= Pointer<spine_timeline_wrapper >
Forward declarations for all non-enum types
spine_to_property
= Pointer<spine_to_property_wrapper >
Forward declarations for all non-enum types
spine_to_rotate
= Pointer<spine_to_rotate_wrapper >
Forward declarations for all non-enum types
spine_to_scale_x
= Pointer<spine_to_scale_x_wrapper >
Forward declarations for all non-enum types
spine_to_scale_y
= Pointer<spine_to_scale_y_wrapper >
Forward declarations for all non-enum types
spine_to_shear_y
= Pointer<spine_to_shear_y_wrapper >
Forward declarations for all non-enum types
spine_to_x
= Pointer<spine_to_x_wrapper >
Forward declarations for all non-enum types
spine_to_y
= Pointer<spine_to_y_wrapper >
Forward declarations for all non-enum types
spine_track_entry
= Pointer<spine_track_entry_wrapper >
Forward declarations for all non-enum types
spine_transform_constraint
= Pointer<spine_transform_constraint_wrapper >
spine_transform_constraint_base
= Pointer<spine_transform_constraint_base_wrapper >
Forward declarations for all non-enum types
spine_transform_constraint_data
= Pointer<spine_transform_constraint_data_wrapper >
Forward declarations for all non-enum types
spine_transform_constraint_pose
= Pointer<spine_transform_constraint_pose_wrapper >
Forward declarations for all non-enum types
spine_transform_constraint_timeline
= Pointer<spine_transform_constraint_timeline_wrapper >
Forward declarations for all non-enum types
spine_translate_timeline
= Pointer<spine_translate_timeline_wrapper >
Forward declarations for all non-enum types
spine_translate_x_timeline
= Pointer<spine_translate_x_timeline_wrapper >
Forward declarations for all non-enum types
spine_translate_y_timeline
= Pointer<spine_translate_y_timeline_wrapper >
Forward declarations for all non-enum types
spine_update
= Pointer<spine_update_wrapper >
Forward declarations for all non-enum types
spine_vertex_attachment
= Pointer<spine_vertex_attachment_wrapper >
Forward declarations for all non-enum types