getMix method

double getMix(
  1. Animation from,
  2. Animation to
)

Returns the mix duration to use when changing from the specified animation to the other on the same track, or the default mix if no mix duration has been set.

Implementation

double getMix(Animation from, Animation to) {
  final result =
      SpineBindings.bindings.spine_animation_state_data_get_mix(_ptr, from.nativePtr.cast(), to.nativePtr.cast());
  return result;
}