Bone class
A node in a skeleton's hierarchy with a transform that affects its children and their attachments. A bone has a number of poses: - getData(): The setup pose data. - getPose(): The unconstrained local pose. Set by animations and application code. - getAppliedPose(): The local pose to use for rendering. Possibly modified by constraints. - World transform: the local pose combined with the parent world transform. Computed on a pose by BonePose::updateWorldTransform(Skeleton) and Skeleton::updateWorldTransform(Physics).
- Inheritance
-
- Object
- PosedActive
- Bone
- Implemented types
Constructors
- Bone(BoneData data, Bone? parent)
-
parentMay be NULL.factory - Bone.from(Bone bone, Bone? parent)
-
Copy constructor. Does not copy the child bones.
factory
-
Bone.fromPointer(Pointer<
spine_bone_wrapper> _ptr)
Properties
- active ← bool
-
no getterinherited
- appliedPose → BonePose
-
The pose to use for rendering. If no constraints modify this pose, this is
the same as getPose(). Otherwise it is a copy of getPose() modified by
constraints.
no setter
- children → ArrayBone
-
The immediate children of this bone.
no setter
- data → BoneData
-
The setup pose data. May be shared with multiple instances.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Returns false when this won't be updated by
Skeleton::updateWorldTransform(Physics) because a skin is required and the
active skin does not contain this item. See Skin::getBones(),
Skin::getConstraints(), PosedData::getSkinRequired(), and
Skeleton::updateCache().
no setterinherited
- isPoseEqualToApplied → bool
-
no setteroverride
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- parent → Bone?
-
The parent bone, or null if this is the root bone.
no setter
- pose → BonePose
-
The unconstrained pose for this object, set by animations and application
code.
no setter
- rtti → Rtti
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrained(
) → void -
Sets the applied pose to the constrained pose, in anticipation of the
applied pose being modified by constraints.
override
-
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetConstrained(
) → void -
Sets the constrained pose to the unconstrained pose, as a starting point
for constraints to be applied.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Skeleton skeleton, Physics physics) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited