BoneData class

BoneData wrapper

Inheritance

Constructors

BoneData(int index, String name, BoneData? parent)
factory
BoneData.fromPointer(Pointer<spine_bone_data_wrapper> _ptr)

Properties

color Color
no setter
hashCode int
The hash code for this object.
no setterinherited
icon String
The bone icon name as it was in Spine, or empty if nonessential data was not exported.
getter/setter pair
iconRotation double
The bone icon's display rotation in degrees, or 0 if nonessential data was not exported.
getter/setter pair
iconSize double
The bone icon's display size scale, or 1 if nonessential data was not exported.
getter/setter pair
index int
The Skeleton::getBones() index for this bone.
no setter
length double
getter/setter pair
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
parent BoneData?
The parent bone, or NULL if this bone is the root.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupPose BonePose
The setup pose that most animations are relative to.
no setter
skinRequired bool
When true, Skeleton::updateWorldTransform(Physics) only updates this constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited
visible bool
getter/setter pair

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited