ClippingAttachment class
ClippingAttachment wrapper
- Inheritance
-
- Object
- Attachment
- VertexAttachment
- ClippingAttachment
Constructors
- ClippingAttachment(String name)
-
factory
-
ClippingAttachment.fromPointer(Pointer<
spine_clipping_attachment_wrapper> _ptr)
Properties
- bones ↔ ArrayInt
-
The bones that affect the vertices. The entries are, for each vertex, the
number of bones affecting the vertex followed by that many bone indices,
which is Skeleton::getBones() index. Empty if this attachment has no
weights.
getter/setter pairinherited
- color → Color
-
no setter
- convex ↔ bool
-
When true the clipping polygon is treated as convex for more efficient
clipping. If the polygon deforms to concave then the convex hull is used.
When false the clipping polygon can be concave and if so has an additional
CPU cost. Inverse clipping always uses convex.
getter/setter pair
- endSlot ↔ SlotData?
-
Clipping is performed between the clipping attachment's slot and the end
slot. If NULL, clipping is done until the end of the skeleton's rendering.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Gets a unique ID for this attachment.
no setterinherited
- inverse ↔ bool
-
When false, everything inside the clipping polygon is visible. When true,
everything outside the clipping polygon is visible and clipping is convex.
getter/setter pair
- name → String
-
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- refCount → int
-
no setterinherited
- rtti → Rtti
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timelineAttachment ↔ Attachment?
-
getter/setter pairinherited
- timelineSlots ↔ ArrayInt
-
getter/setter pairinherited
- vertices ↔ ArrayFloat
-
The vertex positions in the bone's coordinate system. For a non-weighted
attachment, the values are x,y pairs for each vertex. For a weighted
attachment, the values are x,y,weight triplets for each bone affecting
each vertex.
getter/setter pairinherited
- worldVerticesLength ↔ int
-
getter/setter pairinherited
Methods
-
computeWorldVertices(
Skeleton skeleton, Slot slot, int start, int count, ArrayFloat worldVertices, int offset, int stride) → void -
inherited
-
copy(
) → Attachment -
inherited
-
copyTo(
VertexAttachment other) → void -
inherited
-
dereference(
) → void -
inherited
-
dispose(
) → void -
isTimelineActive(
ArraySlot slots, int slotIndex, bool appliedPose) → bool -
Returns true if the slotIndex or any getTimelineSlots() have an attachment
whose getTimelineAttachment() is this attachment.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reference(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited