DrawOrderFolderTimeline class
Changes a subset of the Skeleton::getDrawOrder() draw order.
Constructors
- DrawOrderFolderTimeline(int frameCount, ArrayInt slots, int slotCount)
-
factory
-
DrawOrderFolderTimeline.fromPointer(Pointer<
spine_draw_order_folder_timeline_wrapper> _ptr)
Properties
- additive → bool
-
True if this timeline supports additive blending.
no setterinherited
- duration → double
-
no setterinherited
- frameCount → int
-
no setterinherited
- frameEntries → int
-
no setterinherited
- frames → ArrayFloat
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- instant → bool
-
True if this timeline sets values instantaneously and does not support
interpolation between frames.
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- propertyIds → ArrayPropertyId
-
no setterinherited
- rtti → Rtti
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slots → ArrayInt
-
The Skeleton::getSlots() indices that this timeline affects, in setup
order.
no setter
Methods
-
apply(
Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void -
Applies this timeline to the skeleton.
inherited
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFrame(
int frame, double time, ArrayInt? drawOrder) → void - Sets the time and draw order for the specified frame.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited