EventData class

Stores the setup pose values for an Event.

Constructors

EventData(String name)
factory
EventData.fromPointer(Pointer<spine_event_data_wrapper> _ptr)

Properties

audioPath String
Path to an audio file relative to the audio folder as defined in Spine.
getter/setter pair
getSetupPose Event
The setup values that are shared by all events with this data.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the event, unique across all events in the skeleton.
no setter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupPose2 Event
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited