apply static method
void
apply()
Adjusts the local rotation of the bone so the world position of the tip is as close to the target position as possible. The target is specified in the world coordinate system.
Implementation
static void apply(Skeleton skeleton, BonePose bone, double targetX, double targetY, bool compress, bool stretch,
ScaleYMode scaleYMode, double mix) {
SpineBindings.bindings.spine_ik_constraint_apply_1(
skeleton.nativePtr.cast(), bone.nativePtr.cast(), targetX, targetY, compress, stretch, scaleYMode.value, mix);
}