MeshAttachment class
Attachment that displays a texture region using a mesh.
- Inheritance
-
- Object
- Attachment
- VertexAttachment
- MeshAttachment
Constructors
- MeshAttachment(String name, Sequence? sequence)
-
factory
-
MeshAttachment.fromPointer(Pointer<
spine_mesh_attachment_wrapper> _ptr)
Properties
- bones ↔ ArrayInt
-
The bones that affect the vertices. The entries are, for each vertex, the
number of bones affecting the vertex followed by that many bone indices,
which is Skeleton::getBones() index. Empty if this attachment has no
weights.
getter/setter pairinherited
- color → Color
-
no setter
- edges ↔ ArrayUnsignedShort
-
Vertex index pairs describing edges for controlling triangulation, or
empty if nonessential data was not exported. Mesh triangles do not cross
edges. Triangulation is not performed at runtime.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double
-
getter/setter pair
- hullLength ↔ int
-
getter/setter pair
- id → int
-
Gets a unique ID for this attachment.
no setterinherited
- name → String
-
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- path ↔ String
-
getter/setter pair
- refCount → int
-
no setterinherited
- regionUVs ↔ ArrayFloat
-
getter/setter pair
- rtti → Rtti
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → Sequence
-
no setter
- sourceMesh ↔ MeshAttachment?
-
The source mesh if this is a linked mesh, else NULL. A linked mesh shares
the bones, vertices, regionUVs, triangles, hullLength, edges, width, and
height with the source mesh, but may have a different name or path, and
therefore a different texture region.
getter/setter pair
- timelineAttachment ↔ Attachment?
-
getter/setter pairinherited
- timelineSlots ↔ ArrayInt
-
getter/setter pairinherited
- triangles ↔ ArrayUnsignedShort
-
getter/setter pair
- vertices ↔ ArrayFloat
-
The vertex positions in the bone's coordinate system. For a non-weighted
attachment, the values are x,y pairs for each vertex. For a weighted
attachment, the values are x,y,weight triplets for each bone affecting
each vertex.
getter/setter pairinherited
- width ↔ double
-
getter/setter pair
- worldVerticesLength ↔ int
-
getter/setter pairinherited
Methods
-
computeWorldVertices(
Skeleton skeleton, Slot slot, int start, int count, ArrayFloat worldVertices, int offset, int stride) → void -
inherited
-
copy(
) → Attachment -
inherited
-
copyTo(
VertexAttachment other) → void -
inherited
-
dereference(
) → void -
inherited
-
dispose(
) → void -
isTimelineActive(
ArraySlot slots, int slotIndex, bool appliedPose) → bool -
Returns true if the slotIndex or any getTimelineSlots() have an attachment
whose getTimelineAttachment() is this attachment.
inherited
-
newLinkedMesh(
) → MeshAttachment -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reference(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSequence(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
computeUVs(
TextureRegion? region, ArrayFloat regionUVs, ArrayFloat uvs) → void - Computes UVs for a mesh attachment.