sourceMesh property
MeshAttachment?
get
sourceMesh
The source mesh if this is a linked mesh, else NULL. A linked mesh shares the bones, vertices, regionUVs, triangles, hullLength, edges, width, and height with the source mesh, but may have a different name or path, and therefore a different texture region.
Implementation
MeshAttachment? get sourceMesh {
final result = SpineBindings.bindings.spine_mesh_attachment_get_source_mesh(_ptr);
return result.address == 0 ? null : MeshAttachment.fromPointer(result);
}
set
sourceMesh
(MeshAttachment? value)
Implementation
set sourceMesh(MeshAttachment? value) {
SpineBindings.bindings
.spine_mesh_attachment_set_source_mesh(_ptr, value?.nativePtr.cast() ?? Pointer.fromAddress(0));
}