constantSpeed property
bool
get
constantSpeed
If true, additional calculations are performed to make computing positions along the path more accurate so movement along the path has a constant speed.
Implementation
bool get constantSpeed {
final result = SpineBindings.bindings.spine_path_attachment_get_constant_speed(_ptr);
return result;
}
set
constantSpeed
(bool value)
Implementation
set constantSpeed(bool value) {
SpineBindings.bindings.spine_path_attachment_set_constant_speed(_ptr, value);
}