PathConstraint class
PathConstraint wrapper
- Inheritance
-
- Object
- PosedActive
- PathConstraintBase
- PathConstraint
Constructors
- PathConstraint(PathConstraintData data, Skeleton skeleton)
-
factory
-
PathConstraint.fromPointer(Pointer<
spine_path_constraint_wrapper> _ptr)
Properties
- active ← bool
-
no getterinherited
- appliedPose → PathConstraintPose
-
The pose to use for rendering. If no constraints modify this pose, this is
the same as getPose(). Otherwise it is a copy of getPose() modified by
constraints.
no setterinherited
- bones → ArrayBonePose
-
The bones that will be modified by this path constraint.
no setter
- data → PathConstraintData
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Returns false when this won't be updated by
Skeleton::updateWorldTransform(Physics) because a skin is required and the
active skin does not contain this item. See Skin::getBones(),
Skin::getConstraints(), PosedData::getSkinRequired(), and
Skeleton::updateCache().
no setterinherited
- isPoseEqualToApplied → bool
-
no setterinherited
- isSourceActive → bool
-
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- pose → PathConstraintPose
-
The unconstrained pose for this object, set by animations and application
code.
no setterinherited
- rtti → Rtti
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot ↔ Slot
-
The slot whose path attachment will be used to constrained the bones.
getter/setter pair
Methods
-
constrained(
) → void -
Sets the applied pose to the constrained pose, in anticipation of the
applied pose being modified by constraints.
inherited
-
copy(
Skeleton skeleton) → PathConstraint -
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetConstrained(
) → void -
Sets the constrained pose to the unconstrained pose, as a starting point
for constraints to be applied.
inherited
-
sort(
Skeleton skeleton) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Skeleton skeleton, Physics physics) → void -
Inherited from Update
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited