PhysicsConstraint class
PhysicsConstraint wrapper
- Inheritance
-
- Object
- PosedActive
- PhysicsConstraintBase
- PhysicsConstraint
Constructors
- PhysicsConstraint(PhysicsConstraintData data, Skeleton skeleton)
-
factory
-
PhysicsConstraint.fromPointer(Pointer<
spine_physics_constraint_wrapper> _ptr)
Properties
- active ← bool
-
no getterinherited
- appliedPose → PhysicsConstraintPose
-
The pose to use for rendering. If no constraints modify this pose, this is
the same as getPose(). Otherwise it is a copy of getPose() modified by
constraints.
no setterinherited
- bone ↔ BonePose
-
The bone constrained by this physics constraint.
getter/setter pair
- data → PhysicsConstraintData
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Returns false when this won't be updated by
Skeleton::updateWorldTransform(Physics) because a skin is required and the
active skin does not contain this item. See Skin::getBones(),
Skin::getConstraints(), PosedData::getSkinRequired(), and
Skeleton::updateCache().
no setterinherited
- isPoseEqualToApplied → bool
-
no setterinherited
- isSourceActive → bool
-
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- pose → PhysicsConstraintPose
-
The unconstrained pose for this object, set by animations and application
code.
no setterinherited
- rtti → Rtti
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrained(
) → void -
Sets the applied pose to the constrained pose, in anticipation of the
applied pose being modified by constraints.
inherited
-
copy(
Skeleton skeleton) → PhysicsConstraint -
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
Skeleton skeleton) → void - Resets all physics state that was the result of previous movement. Use this after moving a bone to prevent physics from reacting to the movement.
-
resetConstrained(
) → void -
Sets the constrained pose to the unconstrained pose, as a starting point
for constraints to be applied.
inherited
-
rotate(
double x, double y, double degrees) → void - Rotates the physics constraint so the next update() forces are applied as if the bone rotated around the specified point in world space.
-
sort(
Skeleton skeleton) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
translate(
double x, double y) → void - Translates the physics constraint so the next update() forces are applied as if the bone moved an additional amount in world space.
-
update(
Skeleton skeleton, Physics physics) → void -
Inherited from Update
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited