PhysicsConstraintData class
Stores the setup pose for a PhysicsConstraint.
See https://esotericsoftware.com/spine-physics-constraints Physics constraints in the Spine User Guide.
- Inheritance
- Implemented types
Constructors
- PhysicsConstraintData(String name)
-
factory
-
PhysicsConstraintData.fromPointer(Pointer<
spine_physics_constraint_data_wrapper> _ptr)
Properties
- bone ↔ BoneData
-
The bone constrained by this physics constraint.
getter/setter pair
- dampingGlobal ↔ bool
-
True when this constraint's damping is controlled by global slider
timelines.
getter/setter pair
- gravityGlobal ↔ bool
-
True when this constraint's gravity is controlled by global slider
timelines.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inertiaGlobal ↔ bool
-
True when this constraint's inertia is controlled by global slider
timelines.
getter/setter pair
- limit ↔ double
-
Movement greater than the limit will not have a greater affect on physics.
getter/setter pair
- massGlobal ↔ bool
-
True when this constraint's mass is controlled by global slider timelines.
getter/setter pair
- mixGlobal ↔ bool
-
True when this constraint's mix is controlled by global slider timelines.
getter/setter pair
- name → String
-
no setterinherited
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- rotate ↔ double
-
Physics influence on rotation, 0-1.
getter/setter pair
- rtti → Rtti
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleX ↔ double
-
Physics influence on scaleX, 0-1.
getter/setter pair
- scaleYMode ↔ ScaleYMode
-
Determines how BonePose::getScaleY() changes when getScaleX() sets
BonePose::getScaleX().
getter/setter pair
- setupPose → PhysicsConstraintPose
-
The setup pose that most animations are relative to.
no setter
- shearX ↔ double
-
Physics influence on shearX, 0-1.
getter/setter pair
- skinRequired ↔ bool
-
When true, Skeleton::updateWorldTransform(Physics) only updates this
constraint if the Skeleton::getSkin() contains this constraint.
getter/setter pairinherited
- step ↔ double
-
The time in milliseconds required to advanced the physics simulation one
step.
getter/setter pair
- strengthGlobal ↔ bool
-
True when this constraint's strength is controlled by global slider
timelines.
getter/setter pair
- windGlobal ↔ bool
-
True when this constraint's wind is controlled by global slider timelines.
getter/setter pair
- x ↔ double
-
Physics influence on x translation, 0-1.
getter/setter pair
- y ↔ double
-
Physics influence on y translation, 0-1.
getter/setter pair
Methods
-
createMethod(
Skeleton skeleton) → Constraint -
override
-
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
rttiStatic(
) → Rtti -
override