PosedActive class
A posed object that may be active or inactive.
Constructors
-
PosedActive.fromPointer(Pointer<
spine_posed_active_wrapper> _ptr)
Properties
- active ← bool
-
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Returns false when this won't be updated by
Skeleton::updateWorldTransform(Physics) because a skin is required and the
active skin does not contain this item. See Skin::getBones(),
Skin::getConstraints(), PosedData::getSkinRequired(), and
Skeleton::updateCache().
no setter
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited