RegionAttachment class

Attachment that displays a texture region.

Inheritance

Properties

color Color
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
name String
no setterinherited
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setteroverride
path String
getter/setter pair
refCount int
no setterinherited
rotation double
The local rotation in degrees, counter clockwise.
getter/setter pair
rtti Rtti
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleX double
getter/setter pair
scaleY double
getter/setter pair
sequence Sequence
no setter
timelineAttachment Attachment?
getter/setter pairinherited
timelineSlots ArrayInt
getter/setter pairinherited
width double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

computeWorldVertices(Slot slot, ArrayFloat vertexOffsets, ArrayFloat worldVertices, int offset, int stride) → void
copy() Attachment
inherited
dereference() → void
inherited
dispose() → void
getOffsets(SlotPose pose) ArrayFloat
Returns the vertex offsets for the specified slot pose.
isTimelineActive(ArraySlot slots, int slotIndex, bool appliedPose) bool
Returns true if the slotIndex or any getTimelineSlots() have an attachment whose getTimelineAttachment() is this attachment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reference() → void
inherited
toString() String
A string representation of this object.
inherited
updateSequence() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeUVs(TextureRegion? region, double x, double y, double scaleX, double scaleY, double rotation, double width, double height, ArrayFloat offset, ArrayFloat uvs) → void
Computes UVs and offsets for a region attachment.