Sequence class

Holds texture regions, UVs, and vertex offsets for rendering a region or mesh attachment. Regions must be populated and update() called before use.

Constructors

Sequence(int count, bool pathSuffix)
count The number of texture regions this sequence will display. pathSuffix If true, getPath(String, int) has a numeric suffix. If false, all regions will use the same path, so count should be 1.
factory
Sequence.from(Sequence other)
Copy constructor.
factory
Sequence.fromPointer(Pointer<spine_sequence_wrapper> _ptr)

Properties

digits int
The minimum number of digits in the numeric getPath(String, int) suffix, for zero padding. 0 for no zero padding.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasPathSuffix bool
Returns true if getPath(String, int) has a numeric suffix.
no setter
id int
Returns a unique ID for this sequence.
no setter
nativePtr → Pointer<NativeType>
Get the native pointer for FFI calls
no setter
regions ArrayTextureRegion
The list of texture regions this sequence will display.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupIndex int
The index of the region to show for the setup pose.
getter/setter pair
start int
The starting number for the numeric getPath(String, int) suffix.
getter/setter pair

Methods

dispose() → void
getOffsets(int index) ArrayFloat
Returns vertex offsets from the center of a RegionAttachment. Invalid to call for a MeshAttachment.
getPath(String basePath, int index) String
Returns the specified base path with an optional numeric suffix for the specified index.
getRegion(int index) TextureRegion?
Returns the texture region from getRegions() for the specified index.
getUVs(int index) ArrayFloat
Returns the UVs for the specified index. getRegions() must be populated and update() called before calling this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveIndex(SlotPose pose) int
Returns the getRegions() index for SlotPose::getSequenceIndex().
toString() String
A string representation of this object.
inherited
update(RegionAttachment attachment) → void
Computes UVs and offsets for the specified attachment. Must be called if the regions or attachment properties are changed.
update2(MeshAttachment attachment) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited