Slot class
Organizes attachments for Skeleton drawOrder purposes and provide a place to store state for an attachment.
State cannot be stored in an attachment itself because attachments are stateless and may be shared across multiple skeletons.
- Implemented types
Constructors
- Slot(SlotData data, Skeleton skeleton)
-
factory
-
Slot.fromPointer(Pointer<
spine_slot_wrapper> _ptr)
Properties
- appliedPose → SlotPose
-
The pose to use for rendering. If no constraints modify this pose, this is
the same as getPose(). Otherwise it is a copy of getPose() modified by
constraints.
no setter
- bone → Bone
-
The bone this slot belongs to.
no setter
- data → SlotData
-
The setup pose data. May be shared with multiple instances.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPoseEqualToApplied → bool
-
no setteroverride
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setteroverride
- pose → SlotPose
-
The unconstrained pose for this object, set by animations and application
code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrained(
) → void -
Sets the applied pose to the constrained pose, in anticipation of the
applied pose being modified by constraints.
override
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetConstrained(
) → void -
Sets the constrained pose to the unconstrained pose, as a starting point
for constraints to be applied.
override
-
setupPose(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited