Timeline class abstract
The base class for all timelines.
See Applying Animations in the Spine Runtimes Guide.
Constructors
-
Timeline.fromPointer(Pointer<
spine_timeline_wrapper> _ptr)
Properties
- additive → bool
-
True if this timeline supports additive blending.
no setter
- duration → double
-
no setter
- frameCount → int
-
no setter
- frameEntries → int
-
no setter
- frames → ArrayFloat
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- instant → bool
-
True if this timeline sets values instantaneously and does not support
interpolation between frames.
no setter
-
nativePtr
→ Pointer<
NativeType> -
Get the native pointer for FFI calls
no setter
- propertyIds → ArrayPropertyId
-
no setter
- rtti → Rtti
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Skeleton skeleton, double lastTime, double time, ArrayEvent? events, double alpha, MixFrom from, bool add, bool out, bool appliedPose) → void - Applies this timeline to the skeleton.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
rttiStatic(
) → Rtti