additive property
bool
get
additive
When true, timelines in this animation that support additive have their values added to the setup or current pose values instead of replacing them. Additive can be set for a new track entry only before AnimationState::apply() is next called.
Implementation
bool get additive {
final result = SpineBindings.bindings.spine_track_entry_get_additive(_ptr);
return result;
}
set
additive
(bool value)
Implementation
set additive(bool value) {
SpineBindings.bindings.spine_track_entry_set_additive(_ptr, value);
}