timeScale property
double
get
timeScale
Multiplier for the delta time when this track entry is updated, causing time for this animation to pass slower or faster. Defaults to 1.
Values < 0 are not supported. To play an animation in reverse, use reverse.
mixTime is not affected by track entry time scale, so mixDuration may need to be adjusted to match the animation speed.
When using AnimationState::addAnimation(int, Animation, bool, float) with a delay < = 0, delay is set using the mix duration from AnimationStateData, assuming time scale to be 1. If the time scale is not 1, the delay may need to be adjusted.
See AnimationState::getTimeScale() for affecting all animations.
Implementation
double get timeScale {
final result = SpineBindings.bindings.spine_track_entry_get_time_scale(_ptr);
return result;
}
set
timeScale
(double value)
Implementation
set timeScale(double value) {
SpineBindings.bindings.spine_track_entry_set_time_scale(_ptr, value);
}